import * as msRest from "@azure/ms-rest-js";
import * as Models from "../models";
import { ComputeManagementClientContext } from "../computeManagementClientContext";
/** Class representing a CapacityReservationGroups. */
export declare class CapacityReservationGroups {
    private readonly client;
    /**
     * Create a CapacityReservationGroups.
     * @param {ComputeManagementClientContext} client Reference to the service client.
     */
    constructor(client: ComputeManagementClientContext);
    /**
     * The operation to create or update a capacity reservation group. When updating a capacity
     * reservation group, only tags may be modified. Please refer to https://aka.ms/CapacityReservation
     * for more details.
     * @param resourceGroupName The name of the resource group.
     * @param capacityReservationGroupName The name of the capacity reservation group.
     * @param parameters Parameters supplied to the Create capacity reservation Group.
     * @param [options] The optional parameters
     * @returns Promise<Models.CapacityReservationGroupsCreateOrUpdateResponse>
     */
    createOrUpdate(resourceGroupName: string, capacityReservationGroupName: string, parameters: Models.CapacityReservationGroup, options?: msRest.RequestOptionsBase): Promise<Models.CapacityReservationGroupsCreateOrUpdateResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param capacityReservationGroupName The name of the capacity reservation group.
     * @param parameters Parameters supplied to the Create capacity reservation Group.
     * @param callback The callback
     */
    createOrUpdate(resourceGroupName: string, capacityReservationGroupName: string, parameters: Models.CapacityReservationGroup, callback: msRest.ServiceCallback<Models.CapacityReservationGroup>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param capacityReservationGroupName The name of the capacity reservation group.
     * @param parameters Parameters supplied to the Create capacity reservation Group.
     * @param options The optional parameters
     * @param callback The callback
     */
    createOrUpdate(resourceGroupName: string, capacityReservationGroupName: string, parameters: Models.CapacityReservationGroup, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.CapacityReservationGroup>): void;
    /**
     * The operation to update a capacity reservation group. When updating a capacity reservation
     * group, only tags may be modified.
     * @param resourceGroupName The name of the resource group.
     * @param capacityReservationGroupName The name of the capacity reservation group.
     * @param parameters Parameters supplied to the Update capacity reservation Group operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.CapacityReservationGroupsUpdateResponse>
     */
    update(resourceGroupName: string, capacityReservationGroupName: string, parameters: Models.CapacityReservationGroupUpdate, options?: msRest.RequestOptionsBase): Promise<Models.CapacityReservationGroupsUpdateResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param capacityReservationGroupName The name of the capacity reservation group.
     * @param parameters Parameters supplied to the Update capacity reservation Group operation.
     * @param callback The callback
     */
    update(resourceGroupName: string, capacityReservationGroupName: string, parameters: Models.CapacityReservationGroupUpdate, callback: msRest.ServiceCallback<Models.CapacityReservationGroup>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param capacityReservationGroupName The name of the capacity reservation group.
     * @param parameters Parameters supplied to the Update capacity reservation Group operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    update(resourceGroupName: string, capacityReservationGroupName: string, parameters: Models.CapacityReservationGroupUpdate, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.CapacityReservationGroup>): void;
    /**
     * The operation to delete a capacity reservation group. This operation is allowed only if all the
     * associated resources are disassociated from the reservation group and all capacity reservations
     * under the reservation group have also been deleted. Please refer to
     * https://aka.ms/CapacityReservation for more details.
     * @param resourceGroupName The name of the resource group.
     * @param capacityReservationGroupName The name of the capacity reservation group.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    deleteMethod(resourceGroupName: string, capacityReservationGroupName: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param capacityReservationGroupName The name of the capacity reservation group.
     * @param callback The callback
     */
    deleteMethod(resourceGroupName: string, capacityReservationGroupName: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param capacityReservationGroupName The name of the capacity reservation group.
     * @param options The optional parameters
     * @param callback The callback
     */
    deleteMethod(resourceGroupName: string, capacityReservationGroupName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * The operation that retrieves information about a capacity reservation group.
     * @param resourceGroupName The name of the resource group.
     * @param capacityReservationGroupName The name of the capacity reservation group.
     * @param [options] The optional parameters
     * @returns Promise<Models.CapacityReservationGroupsGetResponse>
     */
    get(resourceGroupName: string, capacityReservationGroupName: string, options?: Models.CapacityReservationGroupsGetOptionalParams): Promise<Models.CapacityReservationGroupsGetResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param capacityReservationGroupName The name of the capacity reservation group.
     * @param callback The callback
     */
    get(resourceGroupName: string, capacityReservationGroupName: string, callback: msRest.ServiceCallback<Models.CapacityReservationGroup>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param capacityReservationGroupName The name of the capacity reservation group.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, capacityReservationGroupName: string, options: Models.CapacityReservationGroupsGetOptionalParams, callback: msRest.ServiceCallback<Models.CapacityReservationGroup>): void;
    /**
     * Lists all of the capacity reservation groups in the specified resource group. Use the nextLink
     * property in the response to get the next page of capacity reservation groups.
     * @param resourceGroupName The name of the resource group.
     * @param [options] The optional parameters
     * @returns Promise<Models.CapacityReservationGroupsListByResourceGroupResponse>
     */
    listByResourceGroup(resourceGroupName: string, options?: Models.CapacityReservationGroupsListByResourceGroupOptionalParams): Promise<Models.CapacityReservationGroupsListByResourceGroupResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param callback The callback
     */
    listByResourceGroup(resourceGroupName: string, callback: msRest.ServiceCallback<Models.CapacityReservationGroupListResult>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByResourceGroup(resourceGroupName: string, options: Models.CapacityReservationGroupsListByResourceGroupOptionalParams, callback: msRest.ServiceCallback<Models.CapacityReservationGroupListResult>): void;
    /**
     * Lists all of the capacity reservation groups in the subscription. Use the nextLink property in
     * the response to get the next page of capacity reservation groups.
     * @param [options] The optional parameters
     * @returns Promise<Models.CapacityReservationGroupsListBySubscriptionResponse>
     */
    listBySubscription(options?: Models.CapacityReservationGroupsListBySubscriptionOptionalParams): Promise<Models.CapacityReservationGroupsListBySubscriptionResponse>;
    /**
     * @param callback The callback
     */
    listBySubscription(callback: msRest.ServiceCallback<Models.CapacityReservationGroupListResult>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    listBySubscription(options: Models.CapacityReservationGroupsListBySubscriptionOptionalParams, callback: msRest.ServiceCallback<Models.CapacityReservationGroupListResult>): void;
    /**
     * Lists all of the capacity reservation groups in the specified resource group. Use the nextLink
     * property in the response to get the next page of capacity reservation groups.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.CapacityReservationGroupsListByResourceGroupNextResponse>
     */
    listByResourceGroupNext(nextPageLink: string, options?: Models.CapacityReservationGroupsListByResourceGroupNextOptionalParams): Promise<Models.CapacityReservationGroupsListByResourceGroupNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listByResourceGroupNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.CapacityReservationGroupListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByResourceGroupNext(nextPageLink: string, options: Models.CapacityReservationGroupsListByResourceGroupNextOptionalParams, callback: msRest.ServiceCallback<Models.CapacityReservationGroupListResult>): void;
    /**
     * Lists all of the capacity reservation groups in the subscription. Use the nextLink property in
     * the response to get the next page of capacity reservation groups.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.CapacityReservationGroupsListBySubscriptionNextResponse>
     */
    listBySubscriptionNext(nextPageLink: string, options?: Models.CapacityReservationGroupsListBySubscriptionNextOptionalParams): Promise<Models.CapacityReservationGroupsListBySubscriptionNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listBySubscriptionNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.CapacityReservationGroupListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listBySubscriptionNext(nextPageLink: string, options: Models.CapacityReservationGroupsListBySubscriptionNextOptionalParams, callback: msRest.ServiceCallback<Models.CapacityReservationGroupListResult>): void;
}
//# sourceMappingURL=capacityReservationGroups.d.ts.map