import * as msRest from "@azure/ms-rest-js";
import * as Models from "../models";
import { ComputeManagementClientContext } from "../computeManagementClientContext";
/** Class representing a DedicatedHostGroups. */
export declare class DedicatedHostGroups {
    private readonly client;
    /**
     * Create a DedicatedHostGroups.
     * @param {ComputeManagementClientContext} client Reference to the service client.
     */
    constructor(client: ComputeManagementClientContext);
    /**
     * Create or update a dedicated host group. For details of Dedicated Host and Dedicated Host Groups
     * please see [Dedicated Host Documentation] (https://go.microsoft.com/fwlink/?linkid=2082596)
     * @param resourceGroupName The name of the resource group.
     * @param hostGroupName The name of the dedicated host group.
     * @param parameters Parameters supplied to the Create Dedicated Host Group.
     * @param [options] The optional parameters
     * @returns Promise<Models.DedicatedHostGroupsCreateOrUpdateResponse>
     */
    createOrUpdate(resourceGroupName: string, hostGroupName: string, parameters: Models.DedicatedHostGroup, options?: msRest.RequestOptionsBase): Promise<Models.DedicatedHostGroupsCreateOrUpdateResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param hostGroupName The name of the dedicated host group.
     * @param parameters Parameters supplied to the Create Dedicated Host Group.
     * @param callback The callback
     */
    createOrUpdate(resourceGroupName: string, hostGroupName: string, parameters: Models.DedicatedHostGroup, callback: msRest.ServiceCallback<Models.DedicatedHostGroup>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param hostGroupName The name of the dedicated host group.
     * @param parameters Parameters supplied to the Create Dedicated Host Group.
     * @param options The optional parameters
     * @param callback The callback
     */
    createOrUpdate(resourceGroupName: string, hostGroupName: string, parameters: Models.DedicatedHostGroup, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DedicatedHostGroup>): void;
    /**
     * Update an dedicated host group.
     * @param resourceGroupName The name of the resource group.
     * @param hostGroupName The name of the dedicated host group.
     * @param parameters Parameters supplied to the Update Dedicated Host Group operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.DedicatedHostGroupsUpdateResponse>
     */
    update(resourceGroupName: string, hostGroupName: string, parameters: Models.DedicatedHostGroupUpdate, options?: msRest.RequestOptionsBase): Promise<Models.DedicatedHostGroupsUpdateResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param hostGroupName The name of the dedicated host group.
     * @param parameters Parameters supplied to the Update Dedicated Host Group operation.
     * @param callback The callback
     */
    update(resourceGroupName: string, hostGroupName: string, parameters: Models.DedicatedHostGroupUpdate, callback: msRest.ServiceCallback<Models.DedicatedHostGroup>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param hostGroupName The name of the dedicated host group.
     * @param parameters Parameters supplied to the Update Dedicated Host Group operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    update(resourceGroupName: string, hostGroupName: string, parameters: Models.DedicatedHostGroupUpdate, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DedicatedHostGroup>): void;
    /**
     * Delete a dedicated host group.
     * @param resourceGroupName The name of the resource group.
     * @param hostGroupName The name of the dedicated host group.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    deleteMethod(resourceGroupName: string, hostGroupName: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param hostGroupName The name of the dedicated host group.
     * @param callback The callback
     */
    deleteMethod(resourceGroupName: string, hostGroupName: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param hostGroupName The name of the dedicated host group.
     * @param options The optional parameters
     * @param callback The callback
     */
    deleteMethod(resourceGroupName: string, hostGroupName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * Retrieves information about a dedicated host group.
     * @param resourceGroupName The name of the resource group.
     * @param hostGroupName The name of the dedicated host group.
     * @param [options] The optional parameters
     * @returns Promise<Models.DedicatedHostGroupsGetResponse>
     */
    get(resourceGroupName: string, hostGroupName: string, options?: Models.DedicatedHostGroupsGetOptionalParams): Promise<Models.DedicatedHostGroupsGetResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param hostGroupName The name of the dedicated host group.
     * @param callback The callback
     */
    get(resourceGroupName: string, hostGroupName: string, callback: msRest.ServiceCallback<Models.DedicatedHostGroup>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param hostGroupName The name of the dedicated host group.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, hostGroupName: string, options: Models.DedicatedHostGroupsGetOptionalParams, callback: msRest.ServiceCallback<Models.DedicatedHostGroup>): void;
    /**
     * Lists all of the dedicated host groups in the specified resource group. Use the nextLink
     * property in the response to get the next page of dedicated host groups.
     * @param resourceGroupName The name of the resource group.
     * @param [options] The optional parameters
     * @returns Promise<Models.DedicatedHostGroupsListByResourceGroupResponse>
     */
    listByResourceGroup(resourceGroupName: string, options?: msRest.RequestOptionsBase): Promise<Models.DedicatedHostGroupsListByResourceGroupResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param callback The callback
     */
    listByResourceGroup(resourceGroupName: string, callback: msRest.ServiceCallback<Models.DedicatedHostGroupListResult>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByResourceGroup(resourceGroupName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DedicatedHostGroupListResult>): void;
    /**
     * Lists all of the dedicated host groups in the subscription. Use the nextLink property in the
     * response to get the next page of dedicated host groups.
     * @param [options] The optional parameters
     * @returns Promise<Models.DedicatedHostGroupsListBySubscriptionResponse>
     */
    listBySubscription(options?: msRest.RequestOptionsBase): Promise<Models.DedicatedHostGroupsListBySubscriptionResponse>;
    /**
     * @param callback The callback
     */
    listBySubscription(callback: msRest.ServiceCallback<Models.DedicatedHostGroupListResult>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    listBySubscription(options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DedicatedHostGroupListResult>): void;
    /**
     * Lists all of the dedicated host groups in the specified resource group. Use the nextLink
     * property in the response to get the next page of dedicated host groups.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.DedicatedHostGroupsListByResourceGroupNextResponse>
     */
    listByResourceGroupNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.DedicatedHostGroupsListByResourceGroupNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listByResourceGroupNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.DedicatedHostGroupListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByResourceGroupNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DedicatedHostGroupListResult>): void;
    /**
     * Lists all of the dedicated host groups in the subscription. Use the nextLink property in the
     * response to get the next page of dedicated host groups.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.DedicatedHostGroupsListBySubscriptionNextResponse>
     */
    listBySubscriptionNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.DedicatedHostGroupsListBySubscriptionNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listBySubscriptionNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.DedicatedHostGroupListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listBySubscriptionNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DedicatedHostGroupListResult>): void;
}
//# sourceMappingURL=dedicatedHostGroups.d.ts.map