import * as msRest from "@azure/ms-rest-js";
import * as Models from "../models";
import { NetworkManagementClientContext } from "../networkManagementClientContext";
/** Class representing a AvailableServiceAliases. */
export declare class AvailableServiceAliases {
    private readonly client;
    /**
     * Create a AvailableServiceAliases.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    constructor(client: NetworkManagementClientContext);
    /**
     * Gets all available service aliases for this subscription in this region.
     * @param location The location.
     * @param [options] The optional parameters
     * @returns Promise<Models.AvailableServiceAliasesListResponse>
     */
    list(location: string, options?: msRest.RequestOptionsBase): Promise<Models.AvailableServiceAliasesListResponse>;
    /**
     * @param location The location.
     * @param callback The callback
     */
    list(location: string, callback: msRest.ServiceCallback<Models.AvailableServiceAliasesResult>): void;
    /**
     * @param location The location.
     * @param options The optional parameters
     * @param callback The callback
     */
    list(location: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.AvailableServiceAliasesResult>): void;
    /**
     * Gets all available service aliases for this resource group in this region.
     * @param resourceGroupName The name of the resource group.
     * @param location The location.
     * @param [options] The optional parameters
     * @returns Promise<Models.AvailableServiceAliasesListByResourceGroupResponse>
     */
    listByResourceGroup(resourceGroupName: string, location: string, options?: msRest.RequestOptionsBase): Promise<Models.AvailableServiceAliasesListByResourceGroupResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param location The location.
     * @param callback The callback
     */
    listByResourceGroup(resourceGroupName: string, location: string, callback: msRest.ServiceCallback<Models.AvailableServiceAliasesResult>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param location The location.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByResourceGroup(resourceGroupName: string, location: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.AvailableServiceAliasesResult>): void;
    /**
     * Gets all available service aliases for this subscription in this region.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.AvailableServiceAliasesListNextResponse>
     */
    listNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.AvailableServiceAliasesListNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.AvailableServiceAliasesResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.AvailableServiceAliasesResult>): void;
    /**
     * Gets all available service aliases for this resource group in this region.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.AvailableServiceAliasesListByResourceGroupNextResponse>
     */
    listByResourceGroupNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.AvailableServiceAliasesListByResourceGroupNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listByResourceGroupNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.AvailableServiceAliasesResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByResourceGroupNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.AvailableServiceAliasesResult>): void;
}
//# sourceMappingURL=availableServiceAliases.d.ts.map