import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import { NetworkManagementClientContext } from "../networkManagementClientContext";
/** Class representing a DdosCustomPolicies. */
export declare class DdosCustomPolicies {
    private readonly client;
    /**
     * Create a DdosCustomPolicies.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    constructor(client: NetworkManagementClientContext);
    /**
     * Deletes the specified DDoS custom policy.
     * @param resourceGroupName The name of the resource group.
     * @param ddosCustomPolicyName The name of the DDoS custom policy.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    deleteMethod(resourceGroupName: string, ddosCustomPolicyName: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * Gets information about the specified DDoS custom policy.
     * @param resourceGroupName The name of the resource group.
     * @param ddosCustomPolicyName The name of the DDoS custom policy.
     * @param [options] The optional parameters
     * @returns Promise<Models.DdosCustomPoliciesGetResponse>
     */
    get(resourceGroupName: string, ddosCustomPolicyName: string, options?: msRest.RequestOptionsBase): Promise<Models.DdosCustomPoliciesGetResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param ddosCustomPolicyName The name of the DDoS custom policy.
     * @param callback The callback
     */
    get(resourceGroupName: string, ddosCustomPolicyName: string, callback: msRest.ServiceCallback<Models.DdosCustomPolicy>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param ddosCustomPolicyName The name of the DDoS custom policy.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, ddosCustomPolicyName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DdosCustomPolicy>): void;
    /**
     * Creates or updates a DDoS custom policy.
     * @param resourceGroupName The name of the resource group.
     * @param ddosCustomPolicyName The name of the DDoS custom policy.
     * @param parameters Parameters supplied to the create or update operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.DdosCustomPoliciesCreateOrUpdateResponse>
     */
    createOrUpdate(resourceGroupName: string, ddosCustomPolicyName: string, parameters: Models.DdosCustomPolicy, options?: msRest.RequestOptionsBase): Promise<Models.DdosCustomPoliciesCreateOrUpdateResponse>;
    /**
     * Update a DDoS custom policy tags.
     * @param resourceGroupName The name of the resource group.
     * @param ddosCustomPolicyName The name of the DDoS custom policy.
     * @param parameters Parameters supplied to update DDoS custom policy resource tags.
     * @param [options] The optional parameters
     * @returns Promise<Models.DdosCustomPoliciesUpdateTagsResponse>
     */
    updateTags(resourceGroupName: string, ddosCustomPolicyName: string, parameters: Models.TagsObject, options?: msRest.RequestOptionsBase): Promise<Models.DdosCustomPoliciesUpdateTagsResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param ddosCustomPolicyName The name of the DDoS custom policy.
     * @param parameters Parameters supplied to update DDoS custom policy resource tags.
     * @param callback The callback
     */
    updateTags(resourceGroupName: string, ddosCustomPolicyName: string, parameters: Models.TagsObject, callback: msRest.ServiceCallback<Models.DdosCustomPolicy>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param ddosCustomPolicyName The name of the DDoS custom policy.
     * @param parameters Parameters supplied to update DDoS custom policy resource tags.
     * @param options The optional parameters
     * @param callback The callback
     */
    updateTags(resourceGroupName: string, ddosCustomPolicyName: string, parameters: Models.TagsObject, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DdosCustomPolicy>): void;
    /**
     * Deletes the specified DDoS custom policy.
     * @param resourceGroupName The name of the resource group.
     * @param ddosCustomPolicyName The name of the DDoS custom policy.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginDeleteMethod(resourceGroupName: string, ddosCustomPolicyName: string, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Creates or updates a DDoS custom policy.
     * @param resourceGroupName The name of the resource group.
     * @param ddosCustomPolicyName The name of the DDoS custom policy.
     * @param parameters Parameters supplied to the create or update operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginCreateOrUpdate(resourceGroupName: string, ddosCustomPolicyName: string, parameters: Models.DdosCustomPolicy, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
}
//# sourceMappingURL=ddosCustomPolicies.d.ts.map