/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/expressRouteCircuitsMappers";
import * as Parameters from "../models/parameters";
/** Class representing a ExpressRouteCircuits. */
var ExpressRouteCircuits = /** @class */ (function () {
    /**
     * Create a ExpressRouteCircuits.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function ExpressRouteCircuits(client) {
        this.client = client;
    }
    /**
     * Deletes the specified express route circuit.
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the express route circuit.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    ExpressRouteCircuits.prototype.deleteMethod = function (resourceGroupName, circuitName, options) {
        return this.beginDeleteMethod(resourceGroupName, circuitName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    ExpressRouteCircuits.prototype.get = function (resourceGroupName, circuitName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            circuitName: circuitName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates or updates an express route circuit.
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the circuit.
     * @param parameters Parameters supplied to the create or update express route circuit operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.ExpressRouteCircuitsCreateOrUpdateResponse>
     */
    ExpressRouteCircuits.prototype.createOrUpdate = function (resourceGroupName, circuitName, parameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, circuitName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    ExpressRouteCircuits.prototype.updateTags = function (resourceGroupName, circuitName, parameters, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            circuitName: circuitName,
            parameters: parameters,
            options: options
        }, updateTagsOperationSpec, callback);
    };
    /**
     * Gets the currently advertised ARP table associated with the express route circuit in a resource
     * group.
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the express route circuit.
     * @param peeringName The name of the peering.
     * @param devicePath The path of the device.
     * @param [options] The optional parameters
     * @returns Promise<Models.ExpressRouteCircuitsListArpTableResponse>
     */
    ExpressRouteCircuits.prototype.listArpTable = function (resourceGroupName, circuitName, peeringName, devicePath, options) {
        return this.beginListArpTable(resourceGroupName, circuitName, peeringName, devicePath, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Gets the currently advertised routes table associated with the express route circuit in a
     * resource group.
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the express route circuit.
     * @param peeringName The name of the peering.
     * @param devicePath The path of the device.
     * @param [options] The optional parameters
     * @returns Promise<Models.ExpressRouteCircuitsListRoutesTableResponse>
     */
    ExpressRouteCircuits.prototype.listRoutesTable = function (resourceGroupName, circuitName, peeringName, devicePath, options) {
        return this.beginListRoutesTable(resourceGroupName, circuitName, peeringName, devicePath, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Gets the currently advertised routes table summary associated with the express route circuit in
     * a resource group.
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the express route circuit.
     * @param peeringName The name of the peering.
     * @param devicePath The path of the device.
     * @param [options] The optional parameters
     * @returns Promise<Models.ExpressRouteCircuitsListRoutesTableSummaryResponse>
     */
    ExpressRouteCircuits.prototype.listRoutesTableSummary = function (resourceGroupName, circuitName, peeringName, devicePath, options) {
        return this.beginListRoutesTableSummary(resourceGroupName, circuitName, peeringName, devicePath, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    ExpressRouteCircuits.prototype.getStats = function (resourceGroupName, circuitName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            circuitName: circuitName,
            options: options
        }, getStatsOperationSpec, callback);
    };
    ExpressRouteCircuits.prototype.getPeeringStats = function (resourceGroupName, circuitName, peeringName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            circuitName: circuitName,
            peeringName: peeringName,
            options: options
        }, getPeeringStatsOperationSpec, callback);
    };
    ExpressRouteCircuits.prototype.list = function (resourceGroupName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            options: options
        }, listOperationSpec, callback);
    };
    ExpressRouteCircuits.prototype.listAll = function (options, callback) {
        return this.client.sendOperationRequest({
            options: options
        }, listAllOperationSpec, callback);
    };
    /**
     * Deletes the specified express route circuit.
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the express route circuit.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ExpressRouteCircuits.prototype.beginDeleteMethod = function (resourceGroupName, circuitName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            circuitName: circuitName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Creates or updates an express route circuit.
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the circuit.
     * @param parameters Parameters supplied to the create or update express route circuit operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ExpressRouteCircuits.prototype.beginCreateOrUpdate = function (resourceGroupName, circuitName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            circuitName: circuitName,
            parameters: parameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    /**
     * Gets the currently advertised ARP table associated with the express route circuit in a resource
     * group.
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the express route circuit.
     * @param peeringName The name of the peering.
     * @param devicePath The path of the device.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ExpressRouteCircuits.prototype.beginListArpTable = function (resourceGroupName, circuitName, peeringName, devicePath, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            circuitName: circuitName,
            peeringName: peeringName,
            devicePath: devicePath,
            options: options
        }, beginListArpTableOperationSpec, options);
    };
    /**
     * Gets the currently advertised routes table associated with the express route circuit in a
     * resource group.
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the express route circuit.
     * @param peeringName The name of the peering.
     * @param devicePath The path of the device.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ExpressRouteCircuits.prototype.beginListRoutesTable = function (resourceGroupName, circuitName, peeringName, devicePath, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            circuitName: circuitName,
            peeringName: peeringName,
            devicePath: devicePath,
            options: options
        }, beginListRoutesTableOperationSpec, options);
    };
    /**
     * Gets the currently advertised routes table summary associated with the express route circuit in
     * a resource group.
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the express route circuit.
     * @param peeringName The name of the peering.
     * @param devicePath The path of the device.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ExpressRouteCircuits.prototype.beginListRoutesTableSummary = function (resourceGroupName, circuitName, peeringName, devicePath, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            circuitName: circuitName,
            peeringName: peeringName,
            devicePath: devicePath,
            options: options
        }, beginListRoutesTableSummaryOperationSpec, options);
    };
    ExpressRouteCircuits.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    ExpressRouteCircuits.prototype.listAllNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listAllNextOperationSpec, callback);
    };
    return ExpressRouteCircuits;
}());
export { ExpressRouteCircuits };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCircuits/{circuitName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.circuitName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCircuit
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var updateTagsOperationSpec = {
    httpMethod: "PATCH",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCircuits/{circuitName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.circuitName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.TagsObject), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCircuit
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var getStatsOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCircuits/{circuitName}/stats",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.circuitName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCircuitStats
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var getPeeringStatsOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCircuits/{circuitName}/peerings/{peeringName}/stats",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.circuitName,
        Parameters.peeringName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCircuitStats
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCircuits",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCircuitListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listAllOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/providers/Microsoft.Network/expressRouteCircuits",
    urlParameters: [
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCircuitListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCircuits/{circuitName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.circuitName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCircuits/{circuitName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.circuitName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.ExpressRouteCircuit), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCircuit
        },
        201: {
            bodyMapper: Mappers.ExpressRouteCircuit
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginListArpTableOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCircuits/{circuitName}/peerings/{peeringName}/arpTables/{devicePath}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.circuitName,
        Parameters.peeringName,
        Parameters.devicePath,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCircuitsArpTableListResult
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginListRoutesTableOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCircuits/{circuitName}/peerings/{peeringName}/routeTables/{devicePath}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.circuitName,
        Parameters.peeringName,
        Parameters.devicePath,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCircuitsRoutesTableListResult
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginListRoutesTableSummaryOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCircuits/{circuitName}/peerings/{peeringName}/routeTablesSummary/{devicePath}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.circuitName,
        Parameters.peeringName,
        Parameters.devicePath,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCircuitsRoutesTableSummaryListResult
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCircuitListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listAllNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCircuitListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=expressRouteCircuits.js.map