import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import { NetworkManagementClientContext } from "../networkManagementClientContext";
/** Class representing a FlowLogs. */
export declare class FlowLogs {
    private readonly client;
    /**
     * Create a FlowLogs.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    constructor(client: NetworkManagementClientContext);
    /**
     * Create or update a flow log for the specified network security group.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param flowLogName The name of the flow log.
     * @param parameters Parameters that define the create or update flow log resource.
     * @param [options] The optional parameters
     * @returns Promise<Models.FlowLogsCreateOrUpdateResponse>
     */
    createOrUpdate(resourceGroupName: string, networkWatcherName: string, flowLogName: string, parameters: Models.FlowLog, options?: msRest.RequestOptionsBase): Promise<Models.FlowLogsCreateOrUpdateResponse>;
    /**
     * Update tags of the specified flow log.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param flowLogName The name of the flow log.
     * @param parameters Parameters supplied to update flow log tags.
     * @param [options] The optional parameters
     * @returns Promise<Models.FlowLogsUpdateTagsResponse>
     */
    updateTags(resourceGroupName: string, networkWatcherName: string, flowLogName: string, parameters: Models.TagsObject, options?: msRest.RequestOptionsBase): Promise<Models.FlowLogsUpdateTagsResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param flowLogName The name of the flow log.
     * @param parameters Parameters supplied to update flow log tags.
     * @param callback The callback
     */
    updateTags(resourceGroupName: string, networkWatcherName: string, flowLogName: string, parameters: Models.TagsObject, callback: msRest.ServiceCallback<Models.FlowLog>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param flowLogName The name of the flow log.
     * @param parameters Parameters supplied to update flow log tags.
     * @param options The optional parameters
     * @param callback The callback
     */
    updateTags(resourceGroupName: string, networkWatcherName: string, flowLogName: string, parameters: Models.TagsObject, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.FlowLog>): void;
    /**
     * Gets a flow log resource by name.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param flowLogName The name of the flow log resource.
     * @param [options] The optional parameters
     * @returns Promise<Models.FlowLogsGetResponse>
     */
    get(resourceGroupName: string, networkWatcherName: string, flowLogName: string, options?: msRest.RequestOptionsBase): Promise<Models.FlowLogsGetResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param flowLogName The name of the flow log resource.
     * @param callback The callback
     */
    get(resourceGroupName: string, networkWatcherName: string, flowLogName: string, callback: msRest.ServiceCallback<Models.FlowLog>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param flowLogName The name of the flow log resource.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, networkWatcherName: string, flowLogName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.FlowLog>): void;
    /**
     * Deletes the specified flow log resource.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param flowLogName The name of the flow log resource.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    deleteMethod(resourceGroupName: string, networkWatcherName: string, flowLogName: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * Lists all flow log resources for the specified Network Watcher.
     * @param resourceGroupName The name of the resource group containing Network Watcher.
     * @param networkWatcherName The name of the Network Watcher resource.
     * @param [options] The optional parameters
     * @returns Promise<Models.FlowLogsListResponse>
     */
    list(resourceGroupName: string, networkWatcherName: string, options?: msRest.RequestOptionsBase): Promise<Models.FlowLogsListResponse>;
    /**
     * @param resourceGroupName The name of the resource group containing Network Watcher.
     * @param networkWatcherName The name of the Network Watcher resource.
     * @param callback The callback
     */
    list(resourceGroupName: string, networkWatcherName: string, callback: msRest.ServiceCallback<Models.FlowLogListResult>): void;
    /**
     * @param resourceGroupName The name of the resource group containing Network Watcher.
     * @param networkWatcherName The name of the Network Watcher resource.
     * @param options The optional parameters
     * @param callback The callback
     */
    list(resourceGroupName: string, networkWatcherName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.FlowLogListResult>): void;
    /**
     * Create or update a flow log for the specified network security group.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param flowLogName The name of the flow log.
     * @param parameters Parameters that define the create or update flow log resource.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginCreateOrUpdate(resourceGroupName: string, networkWatcherName: string, flowLogName: string, parameters: Models.FlowLog, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Deletes the specified flow log resource.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param flowLogName The name of the flow log resource.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginDeleteMethod(resourceGroupName: string, networkWatcherName: string, flowLogName: string, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Lists all flow log resources for the specified Network Watcher.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.FlowLogsListNextResponse>
     */
    listNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.FlowLogsListNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.FlowLogListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.FlowLogListResult>): void;
}
//# sourceMappingURL=flowLogs.d.ts.map