/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/hubVirtualNetworkConnectionsMappers";
import * as Parameters from "../models/parameters";
/** Class representing a HubVirtualNetworkConnections. */
var HubVirtualNetworkConnections = /** @class */ (function () {
    /**
     * Create a HubVirtualNetworkConnections.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function HubVirtualNetworkConnections(client) {
        this.client = client;
    }
    /**
     * Creates a hub virtual network connection if it doesn't exist else updates the existing one.
     * @param resourceGroupName The resource group name of the HubVirtualNetworkConnection.
     * @param virtualHubName The name of the VirtualHub.
     * @param connectionName The name of the HubVirtualNetworkConnection.
     * @param hubVirtualNetworkConnectionParameters Parameters supplied to create or update a hub
     * virtual network connection.
     * @param [options] The optional parameters
     * @returns Promise<Models.HubVirtualNetworkConnectionsCreateOrUpdateResponse>
     */
    HubVirtualNetworkConnections.prototype.createOrUpdate = function (resourceGroupName, virtualHubName, connectionName, hubVirtualNetworkConnectionParameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, virtualHubName, connectionName, hubVirtualNetworkConnectionParameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Deletes a HubVirtualNetworkConnection.
     * @param resourceGroupName The resource group name of the VirtualHub.
     * @param virtualHubName The name of the VirtualHub.
     * @param connectionName The name of the HubVirtualNetworkConnection.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    HubVirtualNetworkConnections.prototype.deleteMethod = function (resourceGroupName, virtualHubName, connectionName, options) {
        return this.beginDeleteMethod(resourceGroupName, virtualHubName, connectionName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    HubVirtualNetworkConnections.prototype.get = function (resourceGroupName, virtualHubName, connectionName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            virtualHubName: virtualHubName,
            connectionName: connectionName,
            options: options
        }, getOperationSpec, callback);
    };
    HubVirtualNetworkConnections.prototype.list = function (resourceGroupName, virtualHubName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            virtualHubName: virtualHubName,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Creates a hub virtual network connection if it doesn't exist else updates the existing one.
     * @param resourceGroupName The resource group name of the HubVirtualNetworkConnection.
     * @param virtualHubName The name of the VirtualHub.
     * @param connectionName The name of the HubVirtualNetworkConnection.
     * @param hubVirtualNetworkConnectionParameters Parameters supplied to create or update a hub
     * virtual network connection.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    HubVirtualNetworkConnections.prototype.beginCreateOrUpdate = function (resourceGroupName, virtualHubName, connectionName, hubVirtualNetworkConnectionParameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualHubName: virtualHubName,
            connectionName: connectionName,
            hubVirtualNetworkConnectionParameters: hubVirtualNetworkConnectionParameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    /**
     * Deletes a HubVirtualNetworkConnection.
     * @param resourceGroupName The resource group name of the VirtualHub.
     * @param virtualHubName The name of the VirtualHub.
     * @param connectionName The name of the HubVirtualNetworkConnection.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    HubVirtualNetworkConnections.prototype.beginDeleteMethod = function (resourceGroupName, virtualHubName, connectionName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualHubName: virtualHubName,
            connectionName: connectionName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    HubVirtualNetworkConnections.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return HubVirtualNetworkConnections;
}());
export { HubVirtualNetworkConnections };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualHubs/{virtualHubName}/hubVirtualNetworkConnections/{connectionName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.virtualHubName,
        Parameters.connectionName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.HubVirtualNetworkConnection
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualHubs/{virtualHubName}/hubVirtualNetworkConnections",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.virtualHubName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ListHubVirtualNetworkConnectionsResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualHubs/{virtualHubName}/hubVirtualNetworkConnections/{connectionName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.virtualHubName,
        Parameters.connectionName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "hubVirtualNetworkConnectionParameters",
        mapper: __assign(__assign({}, Mappers.HubVirtualNetworkConnection), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.HubVirtualNetworkConnection
        },
        201: {
            bodyMapper: Mappers.HubVirtualNetworkConnection
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualHubs/{virtualHubName}/hubVirtualNetworkConnections/{connectionName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.virtualHubName,
        Parameters.connectionName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ListHubVirtualNetworkConnectionsResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=hubVirtualNetworkConnections.js.map