import * as msRest from "@azure/ms-rest-js";
import * as Models from "../models";
import { NetworkManagementClientContext } from "../networkManagementClientContext";
/** Class representing a LoadBalancerOutboundRules. */
export declare class LoadBalancerOutboundRules {
    private readonly client;
    /**
     * Create a LoadBalancerOutboundRules.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    constructor(client: NetworkManagementClientContext);
    /**
     * Gets all the outbound rules in a load balancer.
     * @param resourceGroupName The name of the resource group.
     * @param loadBalancerName The name of the load balancer.
     * @param [options] The optional parameters
     * @returns Promise<Models.LoadBalancerOutboundRulesListResponse>
     */
    list(resourceGroupName: string, loadBalancerName: string, options?: msRest.RequestOptionsBase): Promise<Models.LoadBalancerOutboundRulesListResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param loadBalancerName The name of the load balancer.
     * @param callback The callback
     */
    list(resourceGroupName: string, loadBalancerName: string, callback: msRest.ServiceCallback<Models.LoadBalancerOutboundRuleListResult>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param loadBalancerName The name of the load balancer.
     * @param options The optional parameters
     * @param callback The callback
     */
    list(resourceGroupName: string, loadBalancerName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.LoadBalancerOutboundRuleListResult>): void;
    /**
     * Gets the specified load balancer outbound rule.
     * @param resourceGroupName The name of the resource group.
     * @param loadBalancerName The name of the load balancer.
     * @param outboundRuleName The name of the outbound rule.
     * @param [options] The optional parameters
     * @returns Promise<Models.LoadBalancerOutboundRulesGetResponse>
     */
    get(resourceGroupName: string, loadBalancerName: string, outboundRuleName: string, options?: msRest.RequestOptionsBase): Promise<Models.LoadBalancerOutboundRulesGetResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param loadBalancerName The name of the load balancer.
     * @param outboundRuleName The name of the outbound rule.
     * @param callback The callback
     */
    get(resourceGroupName: string, loadBalancerName: string, outboundRuleName: string, callback: msRest.ServiceCallback<Models.OutboundRule>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param loadBalancerName The name of the load balancer.
     * @param outboundRuleName The name of the outbound rule.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, loadBalancerName: string, outboundRuleName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.OutboundRule>): void;
    /**
     * Gets all the outbound rules in a load balancer.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.LoadBalancerOutboundRulesListNextResponse>
     */
    listNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.LoadBalancerOutboundRulesListNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.LoadBalancerOutboundRuleListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.LoadBalancerOutboundRuleListResult>): void;
}
//# sourceMappingURL=loadBalancerOutboundRules.d.ts.map