/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/networkWatchersMappers";
import * as Parameters from "../models/parameters";
/** Class representing a NetworkWatchers. */
var NetworkWatchers = /** @class */ (function () {
    /**
     * Create a NetworkWatchers.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function NetworkWatchers(client) {
        this.client = client;
    }
    NetworkWatchers.prototype.createOrUpdate = function (resourceGroupName, networkWatcherName, parameters, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            parameters: parameters,
            options: options
        }, createOrUpdateOperationSpec, callback);
    };
    NetworkWatchers.prototype.get = function (resourceGroupName, networkWatcherName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Deletes the specified network watcher resource.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    NetworkWatchers.prototype.deleteMethod = function (resourceGroupName, networkWatcherName, options) {
        return this.beginDeleteMethod(resourceGroupName, networkWatcherName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    NetworkWatchers.prototype.updateTags = function (resourceGroupName, networkWatcherName, parameters, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            parameters: parameters,
            options: options
        }, updateTagsOperationSpec, callback);
    };
    NetworkWatchers.prototype.list = function (resourceGroupName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            options: options
        }, listOperationSpec, callback);
    };
    NetworkWatchers.prototype.listAll = function (options, callback) {
        return this.client.sendOperationRequest({
            options: options
        }, listAllOperationSpec, callback);
    };
    NetworkWatchers.prototype.getTopology = function (resourceGroupName, networkWatcherName, parameters, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            parameters: parameters,
            options: options
        }, getTopologyOperationSpec, callback);
    };
    /**
     * Verify IP flow from the specified VM to a location given the currently configured NSG rules.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param parameters Parameters that define the IP flow to be verified.
     * @param [options] The optional parameters
     * @returns Promise<Models.NetworkWatchersVerifyIPFlowResponse>
     */
    NetworkWatchers.prototype.verifyIPFlow = function (resourceGroupName, networkWatcherName, parameters, options) {
        return this.beginVerifyIPFlow(resourceGroupName, networkWatcherName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Gets the next hop from the specified VM.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param parameters Parameters that define the source and destination endpoint.
     * @param [options] The optional parameters
     * @returns Promise<Models.NetworkWatchersGetNextHopResponse>
     */
    NetworkWatchers.prototype.getNextHop = function (resourceGroupName, networkWatcherName, parameters, options) {
        return this.beginGetNextHop(resourceGroupName, networkWatcherName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Gets the configured and effective security group rules on the specified VM.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param parameters Parameters that define the VM to check security groups for.
     * @param [options] The optional parameters
     * @returns Promise<Models.NetworkWatchersGetVMSecurityRulesResponse>
     */
    NetworkWatchers.prototype.getVMSecurityRules = function (resourceGroupName, networkWatcherName, parameters, options) {
        return this.beginGetVMSecurityRules(resourceGroupName, networkWatcherName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Initiate troubleshooting on a specified resource.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher resource.
     * @param parameters Parameters that define the resource to troubleshoot.
     * @param [options] The optional parameters
     * @returns Promise<Models.NetworkWatchersGetTroubleshootingResponse>
     */
    NetworkWatchers.prototype.getTroubleshooting = function (resourceGroupName, networkWatcherName, parameters, options) {
        return this.beginGetTroubleshooting(resourceGroupName, networkWatcherName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Get the last completed troubleshooting result on a specified resource.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher resource.
     * @param parameters Parameters that define the resource to query the troubleshooting result.
     * @param [options] The optional parameters
     * @returns Promise<Models.NetworkWatchersGetTroubleshootingResultResponse>
     */
    NetworkWatchers.prototype.getTroubleshootingResult = function (resourceGroupName, networkWatcherName, parameters, options) {
        return this.beginGetTroubleshootingResult(resourceGroupName, networkWatcherName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Configures flow log and traffic analytics (optional) on a specified resource.
     * @param resourceGroupName The name of the network watcher resource group.
     * @param networkWatcherName The name of the network watcher resource.
     * @param parameters Parameters that define the configuration of flow log.
     * @param [options] The optional parameters
     * @returns Promise<Models.NetworkWatchersSetFlowLogConfigurationResponse>
     */
    NetworkWatchers.prototype.setFlowLogConfiguration = function (resourceGroupName, networkWatcherName, parameters, options) {
        return this.beginSetFlowLogConfiguration(resourceGroupName, networkWatcherName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Queries status of flow log and traffic analytics (optional) on a specified resource.
     * @param resourceGroupName The name of the network watcher resource group.
     * @param networkWatcherName The name of the network watcher resource.
     * @param parameters Parameters that define a resource to query flow log and traffic analytics
     * (optional) status.
     * @param [options] The optional parameters
     * @returns Promise<Models.NetworkWatchersGetFlowLogStatusResponse>
     */
    NetworkWatchers.prototype.getFlowLogStatus = function (resourceGroupName, networkWatcherName, parameters, options) {
        return this.beginGetFlowLogStatus(resourceGroupName, networkWatcherName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Verifies the possibility of establishing a direct TCP connection from a virtual machine to a
     * given endpoint including another VM or an arbitrary remote server.
     * @param resourceGroupName The name of the network watcher resource group.
     * @param networkWatcherName The name of the network watcher resource.
     * @param parameters Parameters that determine how the connectivity check will be performed.
     * @param [options] The optional parameters
     * @returns Promise<Models.NetworkWatchersCheckConnectivityResponse>
     */
    NetworkWatchers.prototype.checkConnectivity = function (resourceGroupName, networkWatcherName, parameters, options) {
        return this.beginCheckConnectivity(resourceGroupName, networkWatcherName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * NOTE: This feature is currently in preview and still being tested for stability. Gets the
     * relative latency score for internet service providers from a specified location to Azure
     * regions.
     * @param resourceGroupName The name of the network watcher resource group.
     * @param networkWatcherName The name of the network watcher resource.
     * @param parameters Parameters that determine Azure reachability report configuration.
     * @param [options] The optional parameters
     * @returns Promise<Models.NetworkWatchersGetAzureReachabilityReportResponse>
     */
    NetworkWatchers.prototype.getAzureReachabilityReport = function (resourceGroupName, networkWatcherName, parameters, options) {
        return this.beginGetAzureReachabilityReport(resourceGroupName, networkWatcherName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * NOTE: This feature is currently in preview and still being tested for stability. Lists all
     * available internet service providers for a specified Azure region.
     * @param resourceGroupName The name of the network watcher resource group.
     * @param networkWatcherName The name of the network watcher resource.
     * @param parameters Parameters that scope the list of available providers.
     * @param [options] The optional parameters
     * @returns Promise<Models.NetworkWatchersListAvailableProvidersResponse>
     */
    NetworkWatchers.prototype.listAvailableProviders = function (resourceGroupName, networkWatcherName, parameters, options) {
        return this.beginListAvailableProviders(resourceGroupName, networkWatcherName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Gets Network Configuration Diagnostic data to help customers understand and debug network
     * behavior. It provides detailed information on what security rules were applied to a specified
     * traffic flow and the result of evaluating these rules. Customers must provide details of a flow
     * like source, destination, protocol, etc. The API returns whether traffic was allowed or denied,
     * the rules evaluated for the specified flow and the evaluation results.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param parameters Parameters to get network configuration diagnostic.
     * @param [options] The optional parameters
     * @returns Promise<Models.NetworkWatchersGetNetworkConfigurationDiagnosticResponse>
     */
    NetworkWatchers.prototype.getNetworkConfigurationDiagnostic = function (resourceGroupName, networkWatcherName, parameters, options) {
        return this.beginGetNetworkConfigurationDiagnostic(resourceGroupName, networkWatcherName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Deletes the specified network watcher resource.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    NetworkWatchers.prototype.beginDeleteMethod = function (resourceGroupName, networkWatcherName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Verify IP flow from the specified VM to a location given the currently configured NSG rules.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param parameters Parameters that define the IP flow to be verified.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    NetworkWatchers.prototype.beginVerifyIPFlow = function (resourceGroupName, networkWatcherName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            parameters: parameters,
            options: options
        }, beginVerifyIPFlowOperationSpec, options);
    };
    /**
     * Gets the next hop from the specified VM.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param parameters Parameters that define the source and destination endpoint.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    NetworkWatchers.prototype.beginGetNextHop = function (resourceGroupName, networkWatcherName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            parameters: parameters,
            options: options
        }, beginGetNextHopOperationSpec, options);
    };
    /**
     * Gets the configured and effective security group rules on the specified VM.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param parameters Parameters that define the VM to check security groups for.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    NetworkWatchers.prototype.beginGetVMSecurityRules = function (resourceGroupName, networkWatcherName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            parameters: parameters,
            options: options
        }, beginGetVMSecurityRulesOperationSpec, options);
    };
    /**
     * Initiate troubleshooting on a specified resource.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher resource.
     * @param parameters Parameters that define the resource to troubleshoot.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    NetworkWatchers.prototype.beginGetTroubleshooting = function (resourceGroupName, networkWatcherName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            parameters: parameters,
            options: options
        }, beginGetTroubleshootingOperationSpec, options);
    };
    /**
     * Get the last completed troubleshooting result on a specified resource.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher resource.
     * @param parameters Parameters that define the resource to query the troubleshooting result.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    NetworkWatchers.prototype.beginGetTroubleshootingResult = function (resourceGroupName, networkWatcherName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            parameters: parameters,
            options: options
        }, beginGetTroubleshootingResultOperationSpec, options);
    };
    /**
     * Configures flow log and traffic analytics (optional) on a specified resource.
     * @param resourceGroupName The name of the network watcher resource group.
     * @param networkWatcherName The name of the network watcher resource.
     * @param parameters Parameters that define the configuration of flow log.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    NetworkWatchers.prototype.beginSetFlowLogConfiguration = function (resourceGroupName, networkWatcherName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            parameters: parameters,
            options: options
        }, beginSetFlowLogConfigurationOperationSpec, options);
    };
    /**
     * Queries status of flow log and traffic analytics (optional) on a specified resource.
     * @param resourceGroupName The name of the network watcher resource group.
     * @param networkWatcherName The name of the network watcher resource.
     * @param parameters Parameters that define a resource to query flow log and traffic analytics
     * (optional) status.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    NetworkWatchers.prototype.beginGetFlowLogStatus = function (resourceGroupName, networkWatcherName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            parameters: parameters,
            options: options
        }, beginGetFlowLogStatusOperationSpec, options);
    };
    /**
     * Verifies the possibility of establishing a direct TCP connection from a virtual machine to a
     * given endpoint including another VM or an arbitrary remote server.
     * @param resourceGroupName The name of the network watcher resource group.
     * @param networkWatcherName The name of the network watcher resource.
     * @param parameters Parameters that determine how the connectivity check will be performed.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    NetworkWatchers.prototype.beginCheckConnectivity = function (resourceGroupName, networkWatcherName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            parameters: parameters,
            options: options
        }, beginCheckConnectivityOperationSpec, options);
    };
    /**
     * NOTE: This feature is currently in preview and still being tested for stability. Gets the
     * relative latency score for internet service providers from a specified location to Azure
     * regions.
     * @param resourceGroupName The name of the network watcher resource group.
     * @param networkWatcherName The name of the network watcher resource.
     * @param parameters Parameters that determine Azure reachability report configuration.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    NetworkWatchers.prototype.beginGetAzureReachabilityReport = function (resourceGroupName, networkWatcherName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            parameters: parameters,
            options: options
        }, beginGetAzureReachabilityReportOperationSpec, options);
    };
    /**
     * NOTE: This feature is currently in preview and still being tested for stability. Lists all
     * available internet service providers for a specified Azure region.
     * @param resourceGroupName The name of the network watcher resource group.
     * @param networkWatcherName The name of the network watcher resource.
     * @param parameters Parameters that scope the list of available providers.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    NetworkWatchers.prototype.beginListAvailableProviders = function (resourceGroupName, networkWatcherName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            parameters: parameters,
            options: options
        }, beginListAvailableProvidersOperationSpec, options);
    };
    /**
     * Gets Network Configuration Diagnostic data to help customers understand and debug network
     * behavior. It provides detailed information on what security rules were applied to a specified
     * traffic flow and the result of evaluating these rules. Customers must provide details of a flow
     * like source, destination, protocol, etc. The API returns whether traffic was allowed or denied,
     * the rules evaluated for the specified flow and the evaluation results.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param parameters Parameters to get network configuration diagnostic.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    NetworkWatchers.prototype.beginGetNetworkConfigurationDiagnostic = function (resourceGroupName, networkWatcherName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            parameters: parameters,
            options: options
        }, beginGetNetworkConfigurationDiagnosticOperationSpec, options);
    };
    return NetworkWatchers;
}());
export { NetworkWatchers };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var createOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.NetworkWatcher), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.NetworkWatcher
        },
        201: {
            bodyMapper: Mappers.NetworkWatcher
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.NetworkWatcher
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var updateTagsOperationSpec = {
    httpMethod: "PATCH",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.TagsObject), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.NetworkWatcher
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.NetworkWatcherListResult
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var listAllOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/providers/Microsoft.Network/networkWatchers",
    urlParameters: [
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.NetworkWatcherListResult
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var getTopologyOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/topology",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.TopologyParameters), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.Topology
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var beginVerifyIPFlowOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/ipFlowVerify",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.VerificationIPFlowParameters), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.VerificationIPFlowResult
        },
        202: {
            bodyMapper: Mappers.VerificationIPFlowResult
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var beginGetNextHopOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/nextHop",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.NextHopParameters), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.NextHopResult
        },
        202: {
            bodyMapper: Mappers.NextHopResult
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var beginGetVMSecurityRulesOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/securityGroupView",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.SecurityGroupViewParameters), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.SecurityGroupViewResult
        },
        202: {
            bodyMapper: Mappers.SecurityGroupViewResult
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var beginGetTroubleshootingOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/troubleshoot",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.TroubleshootingParameters), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.TroubleshootingResult
        },
        202: {
            bodyMapper: Mappers.TroubleshootingResult
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var beginGetTroubleshootingResultOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/queryTroubleshootResult",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.QueryTroubleshootingParameters), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.TroubleshootingResult
        },
        202: {
            bodyMapper: Mappers.TroubleshootingResult
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var beginSetFlowLogConfigurationOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/configureFlowLog",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.FlowLogInformation), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.FlowLogInformation
        },
        202: {
            bodyMapper: Mappers.FlowLogInformation
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var beginGetFlowLogStatusOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/queryFlowLogStatus",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.FlowLogStatusParameters), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.FlowLogInformation
        },
        202: {
            bodyMapper: Mappers.FlowLogInformation
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var beginCheckConnectivityOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/connectivityCheck",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.ConnectivityParameters), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.ConnectivityInformation
        },
        202: {
            bodyMapper: Mappers.ConnectivityInformation
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var beginGetAzureReachabilityReportOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/azureReachabilityReport",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.AzureReachabilityReportParameters), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.AzureReachabilityReport
        },
        202: {
            bodyMapper: Mappers.AzureReachabilityReport
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var beginListAvailableProvidersOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/availableProvidersList",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.AvailableProvidersListParameters), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.AvailableProvidersList
        },
        202: {
            bodyMapper: Mappers.AvailableProvidersList
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var beginGetNetworkConfigurationDiagnosticOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/networkConfigurationDiagnostic",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.NetworkConfigurationDiagnosticParameters), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.NetworkConfigurationDiagnosticResponse
        },
        202: {
            bodyMapper: Mappers.NetworkConfigurationDiagnosticResponse
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
//# sourceMappingURL=networkWatchers.js.map