/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/packetCapturesMappers";
import * as Parameters from "../models/parameters";
/** Class representing a PacketCaptures. */
var PacketCaptures = /** @class */ (function () {
    /**
     * Create a PacketCaptures.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function PacketCaptures(client) {
        this.client = client;
    }
    /**
     * Create and start a packet capture on the specified VM.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param packetCaptureName The name of the packet capture session.
     * @param parameters Parameters that define the create packet capture operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.PacketCapturesCreateResponse>
     */
    PacketCaptures.prototype.create = function (resourceGroupName, networkWatcherName, packetCaptureName, parameters, options) {
        return this.beginCreate(resourceGroupName, networkWatcherName, packetCaptureName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    PacketCaptures.prototype.get = function (resourceGroupName, networkWatcherName, packetCaptureName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            packetCaptureName: packetCaptureName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Deletes the specified packet capture session.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param packetCaptureName The name of the packet capture session.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    PacketCaptures.prototype.deleteMethod = function (resourceGroupName, networkWatcherName, packetCaptureName, options) {
        return this.beginDeleteMethod(resourceGroupName, networkWatcherName, packetCaptureName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Stops a specified packet capture session.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param packetCaptureName The name of the packet capture session.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    PacketCaptures.prototype.stop = function (resourceGroupName, networkWatcherName, packetCaptureName, options) {
        return this.beginStop(resourceGroupName, networkWatcherName, packetCaptureName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Query the status of a running packet capture session.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the Network Watcher resource.
     * @param packetCaptureName The name given to the packet capture session.
     * @param [options] The optional parameters
     * @returns Promise<Models.PacketCapturesGetStatusResponse>
     */
    PacketCaptures.prototype.getStatus = function (resourceGroupName, networkWatcherName, packetCaptureName, options) {
        return this.beginGetStatus(resourceGroupName, networkWatcherName, packetCaptureName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    PacketCaptures.prototype.list = function (resourceGroupName, networkWatcherName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Create and start a packet capture on the specified VM.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param packetCaptureName The name of the packet capture session.
     * @param parameters Parameters that define the create packet capture operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    PacketCaptures.prototype.beginCreate = function (resourceGroupName, networkWatcherName, packetCaptureName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            packetCaptureName: packetCaptureName,
            parameters: parameters,
            options: options
        }, beginCreateOperationSpec, options);
    };
    /**
     * Deletes the specified packet capture session.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param packetCaptureName The name of the packet capture session.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    PacketCaptures.prototype.beginDeleteMethod = function (resourceGroupName, networkWatcherName, packetCaptureName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            packetCaptureName: packetCaptureName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Stops a specified packet capture session.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param packetCaptureName The name of the packet capture session.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    PacketCaptures.prototype.beginStop = function (resourceGroupName, networkWatcherName, packetCaptureName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            packetCaptureName: packetCaptureName,
            options: options
        }, beginStopOperationSpec, options);
    };
    /**
     * Query the status of a running packet capture session.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the Network Watcher resource.
     * @param packetCaptureName The name given to the packet capture session.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    PacketCaptures.prototype.beginGetStatus = function (resourceGroupName, networkWatcherName, packetCaptureName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            packetCaptureName: packetCaptureName,
            options: options
        }, beginGetStatusOperationSpec, options);
    };
    return PacketCaptures;
}());
export { PacketCaptures };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/packetCaptures/{packetCaptureName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.packetCaptureName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PacketCaptureResult
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/packetCaptures",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PacketCaptureListResult
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var beginCreateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/packetCaptures/{packetCaptureName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.packetCaptureName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.PacketCapture), { required: true })
    },
    responses: {
        201: {
            bodyMapper: Mappers.PacketCaptureResult
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/packetCaptures/{packetCaptureName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.packetCaptureName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var beginStopOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/packetCaptures/{packetCaptureName}/stop",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.packetCaptureName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var beginGetStatusOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/packetCaptures/{packetCaptureName}/queryStatus",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.packetCaptureName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PacketCaptureQueryStatusResult
        },
        202: {
            bodyMapper: Mappers.PacketCaptureQueryStatusResult
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
//# sourceMappingURL=packetCaptures.js.map