import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import { NetworkManagementClientContext } from "../networkManagementClientContext";
/** Class representing a PrivateLinkServices. */
export declare class PrivateLinkServices {
    private readonly client;
    /**
     * Create a PrivateLinkServices.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    constructor(client: NetworkManagementClientContext);
    /**
     * Deletes the specified private link service.
     * @param resourceGroupName The name of the resource group.
     * @param serviceName The name of the private link service.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    deleteMethod(resourceGroupName: string, serviceName: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * Gets the specified private link service by resource group.
     * @param resourceGroupName The name of the resource group.
     * @param serviceName The name of the private link service.
     * @param [options] The optional parameters
     * @returns Promise<Models.PrivateLinkServicesGetResponse>
     */
    get(resourceGroupName: string, serviceName: string, options?: Models.PrivateLinkServicesGetOptionalParams): Promise<Models.PrivateLinkServicesGetResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param serviceName The name of the private link service.
     * @param callback The callback
     */
    get(resourceGroupName: string, serviceName: string, callback: msRest.ServiceCallback<Models.PrivateLinkService>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param serviceName The name of the private link service.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, serviceName: string, options: Models.PrivateLinkServicesGetOptionalParams, callback: msRest.ServiceCallback<Models.PrivateLinkService>): void;
    /**
     * Creates or updates an private link service in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param serviceName The name of the private link service.
     * @param parameters Parameters supplied to the create or update private link service operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.PrivateLinkServicesCreateOrUpdateResponse>
     */
    createOrUpdate(resourceGroupName: string, serviceName: string, parameters: Models.PrivateLinkService, options?: msRest.RequestOptionsBase): Promise<Models.PrivateLinkServicesCreateOrUpdateResponse>;
    /**
     * Gets all private link services in a resource group.
     * @param resourceGroupName The name of the resource group.
     * @param [options] The optional parameters
     * @returns Promise<Models.PrivateLinkServicesListResponse>
     */
    list(resourceGroupName: string, options?: msRest.RequestOptionsBase): Promise<Models.PrivateLinkServicesListResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param callback The callback
     */
    list(resourceGroupName: string, callback: msRest.ServiceCallback<Models.PrivateLinkServiceListResult>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param options The optional parameters
     * @param callback The callback
     */
    list(resourceGroupName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.PrivateLinkServiceListResult>): void;
    /**
     * Gets all private link service in a subscription.
     * @param [options] The optional parameters
     * @returns Promise<Models.PrivateLinkServicesListBySubscriptionResponse>
     */
    listBySubscription(options?: msRest.RequestOptionsBase): Promise<Models.PrivateLinkServicesListBySubscriptionResponse>;
    /**
     * @param callback The callback
     */
    listBySubscription(callback: msRest.ServiceCallback<Models.PrivateLinkServiceListResult>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    listBySubscription(options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.PrivateLinkServiceListResult>): void;
    /**
     * Get the specific private end point connection by specific private link service in the resource
     * group.
     * @param resourceGroupName The name of the resource group.
     * @param serviceName The name of the private link service.
     * @param peConnectionName The name of the private end point connection.
     * @param [options] The optional parameters
     * @returns Promise<Models.PrivateLinkServicesGetPrivateEndpointConnectionResponse>
     */
    getPrivateEndpointConnection(resourceGroupName: string, serviceName: string, peConnectionName: string, options?: Models.PrivateLinkServicesGetPrivateEndpointConnectionOptionalParams): Promise<Models.PrivateLinkServicesGetPrivateEndpointConnectionResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param serviceName The name of the private link service.
     * @param peConnectionName The name of the private end point connection.
     * @param callback The callback
     */
    getPrivateEndpointConnection(resourceGroupName: string, serviceName: string, peConnectionName: string, callback: msRest.ServiceCallback<Models.PrivateEndpointConnection>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param serviceName The name of the private link service.
     * @param peConnectionName The name of the private end point connection.
     * @param options The optional parameters
     * @param callback The callback
     */
    getPrivateEndpointConnection(resourceGroupName: string, serviceName: string, peConnectionName: string, options: Models.PrivateLinkServicesGetPrivateEndpointConnectionOptionalParams, callback: msRest.ServiceCallback<Models.PrivateEndpointConnection>): void;
    /**
     * Approve or reject private end point connection for a private link service in a subscription.
     * @param resourceGroupName The name of the resource group.
     * @param serviceName The name of the private link service.
     * @param peConnectionName The name of the private end point connection.
     * @param parameters Parameters supplied to approve or reject the private end point connection.
     * @param [options] The optional parameters
     * @returns Promise<Models.PrivateLinkServicesUpdatePrivateEndpointConnectionResponse>
     */
    updatePrivateEndpointConnection(resourceGroupName: string, serviceName: string, peConnectionName: string, parameters: Models.PrivateEndpointConnection, options?: msRest.RequestOptionsBase): Promise<Models.PrivateLinkServicesUpdatePrivateEndpointConnectionResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param serviceName The name of the private link service.
     * @param peConnectionName The name of the private end point connection.
     * @param parameters Parameters supplied to approve or reject the private end point connection.
     * @param callback The callback
     */
    updatePrivateEndpointConnection(resourceGroupName: string, serviceName: string, peConnectionName: string, parameters: Models.PrivateEndpointConnection, callback: msRest.ServiceCallback<Models.PrivateEndpointConnection>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param serviceName The name of the private link service.
     * @param peConnectionName The name of the private end point connection.
     * @param parameters Parameters supplied to approve or reject the private end point connection.
     * @param options The optional parameters
     * @param callback The callback
     */
    updatePrivateEndpointConnection(resourceGroupName: string, serviceName: string, peConnectionName: string, parameters: Models.PrivateEndpointConnection, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.PrivateEndpointConnection>): void;
    /**
     * Delete private end point connection for a private link service in a subscription.
     * @param resourceGroupName The name of the resource group.
     * @param serviceName The name of the private link service.
     * @param peConnectionName The name of the private end point connection.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    deletePrivateEndpointConnection(resourceGroupName: string, serviceName: string, peConnectionName: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * Gets all private end point connections for a specific private link service.
     * @param resourceGroupName The name of the resource group.
     * @param serviceName The name of the private link service.
     * @param [options] The optional parameters
     * @returns Promise<Models.PrivateLinkServicesListPrivateEndpointConnectionsResponse>
     */
    listPrivateEndpointConnections(resourceGroupName: string, serviceName: string, options?: msRest.RequestOptionsBase): Promise<Models.PrivateLinkServicesListPrivateEndpointConnectionsResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param serviceName The name of the private link service.
     * @param callback The callback
     */
    listPrivateEndpointConnections(resourceGroupName: string, serviceName: string, callback: msRest.ServiceCallback<Models.PrivateEndpointConnectionListResult>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param serviceName The name of the private link service.
     * @param options The optional parameters
     * @param callback The callback
     */
    listPrivateEndpointConnections(resourceGroupName: string, serviceName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.PrivateEndpointConnectionListResult>): void;
    /**
     * Checks whether the subscription is visible to private link service.
     * @param location The location of the domain name.
     * @param parameters The request body of CheckPrivateLinkService API call.
     * @param [options] The optional parameters
     * @returns Promise<Models.PrivateLinkServicesCheckPrivateLinkServiceVisibilityResponse>
     */
    checkPrivateLinkServiceVisibility(location: string, parameters: Models.CheckPrivateLinkServiceVisibilityRequest, options?: msRest.RequestOptionsBase): Promise<Models.PrivateLinkServicesCheckPrivateLinkServiceVisibilityResponse>;
    /**
     * Checks whether the subscription is visible to private link service in the specified resource
     * group.
     * @param location The location of the domain name.
     * @param resourceGroupName The name of the resource group.
     * @param parameters The request body of CheckPrivateLinkService API call.
     * @param [options] The optional parameters
     * @returns
     * Promise<Models.PrivateLinkServicesCheckPrivateLinkServiceVisibilityByResourceGroupResponse>
     */
    checkPrivateLinkServiceVisibilityByResourceGroup(location: string, resourceGroupName: string, parameters: Models.CheckPrivateLinkServiceVisibilityRequest, options?: msRest.RequestOptionsBase): Promise<Models.PrivateLinkServicesCheckPrivateLinkServiceVisibilityByResourceGroupResponse>;
    /**
     * Returns all of the private link service ids that can be linked to a Private Endpoint with auto
     * approved in this subscription in this region.
     * @param location The location of the domain name.
     * @param [options] The optional parameters
     * @returns Promise<Models.PrivateLinkServicesListAutoApprovedPrivateLinkServicesResponse>
     */
    listAutoApprovedPrivateLinkServices(location: string, options?: msRest.RequestOptionsBase): Promise<Models.PrivateLinkServicesListAutoApprovedPrivateLinkServicesResponse>;
    /**
     * @param location The location of the domain name.
     * @param callback The callback
     */
    listAutoApprovedPrivateLinkServices(location: string, callback: msRest.ServiceCallback<Models.AutoApprovedPrivateLinkServicesResult>): void;
    /**
     * @param location The location of the domain name.
     * @param options The optional parameters
     * @param callback The callback
     */
    listAutoApprovedPrivateLinkServices(location: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.AutoApprovedPrivateLinkServicesResult>): void;
    /**
     * Returns all of the private link service ids that can be linked to a Private Endpoint with auto
     * approved in this subscription in this region.
     * @param location The location of the domain name.
     * @param resourceGroupName The name of the resource group.
     * @param [options] The optional parameters
     * @returns
     * Promise<Models.PrivateLinkServicesListAutoApprovedPrivateLinkServicesByResourceGroupResponse>
     */
    listAutoApprovedPrivateLinkServicesByResourceGroup(location: string, resourceGroupName: string, options?: msRest.RequestOptionsBase): Promise<Models.PrivateLinkServicesListAutoApprovedPrivateLinkServicesByResourceGroupResponse>;
    /**
     * @param location The location of the domain name.
     * @param resourceGroupName The name of the resource group.
     * @param callback The callback
     */
    listAutoApprovedPrivateLinkServicesByResourceGroup(location: string, resourceGroupName: string, callback: msRest.ServiceCallback<Models.AutoApprovedPrivateLinkServicesResult>): void;
    /**
     * @param location The location of the domain name.
     * @param resourceGroupName The name of the resource group.
     * @param options The optional parameters
     * @param callback The callback
     */
    listAutoApprovedPrivateLinkServicesByResourceGroup(location: string, resourceGroupName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.AutoApprovedPrivateLinkServicesResult>): void;
    /**
     * Deletes the specified private link service.
     * @param resourceGroupName The name of the resource group.
     * @param serviceName The name of the private link service.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginDeleteMethod(resourceGroupName: string, serviceName: string, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Creates or updates an private link service in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param serviceName The name of the private link service.
     * @param parameters Parameters supplied to the create or update private link service operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginCreateOrUpdate(resourceGroupName: string, serviceName: string, parameters: Models.PrivateLinkService, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Delete private end point connection for a private link service in a subscription.
     * @param resourceGroupName The name of the resource group.
     * @param serviceName The name of the private link service.
     * @param peConnectionName The name of the private end point connection.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginDeletePrivateEndpointConnection(resourceGroupName: string, serviceName: string, peConnectionName: string, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Checks whether the subscription is visible to private link service.
     * @param location The location of the domain name.
     * @param parameters The request body of CheckPrivateLinkService API call.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginCheckPrivateLinkServiceVisibility(location: string, parameters: Models.CheckPrivateLinkServiceVisibilityRequest, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Checks whether the subscription is visible to private link service in the specified resource
     * group.
     * @param location The location of the domain name.
     * @param resourceGroupName The name of the resource group.
     * @param parameters The request body of CheckPrivateLinkService API call.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginCheckPrivateLinkServiceVisibilityByResourceGroup(location: string, resourceGroupName: string, parameters: Models.CheckPrivateLinkServiceVisibilityRequest, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Gets all private link services in a resource group.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.PrivateLinkServicesListNextResponse>
     */
    listNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.PrivateLinkServicesListNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.PrivateLinkServiceListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.PrivateLinkServiceListResult>): void;
    /**
     * Gets all private link service in a subscription.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.PrivateLinkServicesListBySubscriptionNextResponse>
     */
    listBySubscriptionNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.PrivateLinkServicesListBySubscriptionNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listBySubscriptionNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.PrivateLinkServiceListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listBySubscriptionNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.PrivateLinkServiceListResult>): void;
    /**
     * Gets all private end point connections for a specific private link service.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.PrivateLinkServicesListPrivateEndpointConnectionsNextResponse>
     */
    listPrivateEndpointConnectionsNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.PrivateLinkServicesListPrivateEndpointConnectionsNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listPrivateEndpointConnectionsNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.PrivateEndpointConnectionListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listPrivateEndpointConnectionsNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.PrivateEndpointConnectionListResult>): void;
    /**
     * Returns all of the private link service ids that can be linked to a Private Endpoint with auto
     * approved in this subscription in this region.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.PrivateLinkServicesListAutoApprovedPrivateLinkServicesNextResponse>
     */
    listAutoApprovedPrivateLinkServicesNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.PrivateLinkServicesListAutoApprovedPrivateLinkServicesNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listAutoApprovedPrivateLinkServicesNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.AutoApprovedPrivateLinkServicesResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listAutoApprovedPrivateLinkServicesNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.AutoApprovedPrivateLinkServicesResult>): void;
    /**
     * Returns all of the private link service ids that can be linked to a Private Endpoint with auto
     * approved in this subscription in this region.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns
     * Promise<Models.PrivateLinkServicesListAutoApprovedPrivateLinkServicesByResourceGroupNextResponse>
     */
    listAutoApprovedPrivateLinkServicesByResourceGroupNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.PrivateLinkServicesListAutoApprovedPrivateLinkServicesByResourceGroupNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listAutoApprovedPrivateLinkServicesByResourceGroupNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.AutoApprovedPrivateLinkServicesResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listAutoApprovedPrivateLinkServicesByResourceGroupNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.AutoApprovedPrivateLinkServicesResult>): void;
}
//# sourceMappingURL=privateLinkServices.d.ts.map