/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/routesMappers";
import * as Parameters from "../models/parameters";
/** Class representing a Routes. */
var Routes = /** @class */ (function () {
    /**
     * Create a Routes.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function Routes(client) {
        this.client = client;
    }
    /**
     * Deletes the specified route from a route table.
     * @param resourceGroupName The name of the resource group.
     * @param routeTableName The name of the route table.
     * @param routeName The name of the route.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    Routes.prototype.deleteMethod = function (resourceGroupName, routeTableName, routeName, options) {
        return this.beginDeleteMethod(resourceGroupName, routeTableName, routeName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    Routes.prototype.get = function (resourceGroupName, routeTableName, routeName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            routeTableName: routeTableName,
            routeName: routeName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates or updates a route in the specified route table.
     * @param resourceGroupName The name of the resource group.
     * @param routeTableName The name of the route table.
     * @param routeName The name of the route.
     * @param routeParameters Parameters supplied to the create or update route operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.RoutesCreateOrUpdateResponse>
     */
    Routes.prototype.createOrUpdate = function (resourceGroupName, routeTableName, routeName, routeParameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, routeTableName, routeName, routeParameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    Routes.prototype.list = function (resourceGroupName, routeTableName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            routeTableName: routeTableName,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Deletes the specified route from a route table.
     * @param resourceGroupName The name of the resource group.
     * @param routeTableName The name of the route table.
     * @param routeName The name of the route.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    Routes.prototype.beginDeleteMethod = function (resourceGroupName, routeTableName, routeName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            routeTableName: routeTableName,
            routeName: routeName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Creates or updates a route in the specified route table.
     * @param resourceGroupName The name of the resource group.
     * @param routeTableName The name of the route table.
     * @param routeName The name of the route.
     * @param routeParameters Parameters supplied to the create or update route operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    Routes.prototype.beginCreateOrUpdate = function (resourceGroupName, routeTableName, routeName, routeParameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            routeTableName: routeTableName,
            routeName: routeName,
            routeParameters: routeParameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    Routes.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return Routes;
}());
export { Routes };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/routeTables/{routeTableName}/routes/{routeName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.routeTableName,
        Parameters.routeName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.Route
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/routeTables/{routeTableName}/routes",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.routeTableName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.RouteListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/routeTables/{routeTableName}/routes/{routeName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.routeTableName,
        Parameters.routeName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/routeTables/{routeTableName}/routes/{routeName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.routeTableName,
        Parameters.routeName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "routeParameters",
        mapper: __assign(__assign({}, Mappers.Route), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.Route
        },
        201: {
            bodyMapper: Mappers.Route
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.RouteListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=routes.js.map