/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/securityPartnerProvidersMappers";
import * as Parameters from "../models/parameters";
/** Class representing a SecurityPartnerProviders. */
var SecurityPartnerProviders = /** @class */ (function () {
    /**
     * Create a SecurityPartnerProviders.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function SecurityPartnerProviders(client) {
        this.client = client;
    }
    /**
     * Deletes the specified Security Partner Provider.
     * @param resourceGroupName The name of the resource group.
     * @param securityPartnerProviderName The name of the Security Partner Provider.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    SecurityPartnerProviders.prototype.deleteMethod = function (resourceGroupName, securityPartnerProviderName, options) {
        return this.beginDeleteMethod(resourceGroupName, securityPartnerProviderName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    SecurityPartnerProviders.prototype.get = function (resourceGroupName, securityPartnerProviderName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            securityPartnerProviderName: securityPartnerProviderName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates or updates the specified Security Partner Provider.
     * @param resourceGroupName The name of the resource group.
     * @param securityPartnerProviderName The name of the Security Partner Provider.
     * @param parameters Parameters supplied to the create or update Security Partner Provider
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.SecurityPartnerProvidersCreateOrUpdateResponse>
     */
    SecurityPartnerProviders.prototype.createOrUpdate = function (resourceGroupName, securityPartnerProviderName, parameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, securityPartnerProviderName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    SecurityPartnerProviders.prototype.updateTags = function (resourceGroupName, securityPartnerProviderName, parameters, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            securityPartnerProviderName: securityPartnerProviderName,
            parameters: parameters,
            options: options
        }, updateTagsOperationSpec, callback);
    };
    SecurityPartnerProviders.prototype.listByResourceGroup = function (resourceGroupName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            options: options
        }, listByResourceGroupOperationSpec, callback);
    };
    SecurityPartnerProviders.prototype.list = function (options, callback) {
        return this.client.sendOperationRequest({
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Deletes the specified Security Partner Provider.
     * @param resourceGroupName The name of the resource group.
     * @param securityPartnerProviderName The name of the Security Partner Provider.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    SecurityPartnerProviders.prototype.beginDeleteMethod = function (resourceGroupName, securityPartnerProviderName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            securityPartnerProviderName: securityPartnerProviderName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Creates or updates the specified Security Partner Provider.
     * @param resourceGroupName The name of the resource group.
     * @param securityPartnerProviderName The name of the Security Partner Provider.
     * @param parameters Parameters supplied to the create or update Security Partner Provider
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    SecurityPartnerProviders.prototype.beginCreateOrUpdate = function (resourceGroupName, securityPartnerProviderName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            securityPartnerProviderName: securityPartnerProviderName,
            parameters: parameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    SecurityPartnerProviders.prototype.listByResourceGroupNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listByResourceGroupNextOperationSpec, callback);
    };
    SecurityPartnerProviders.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return SecurityPartnerProviders;
}());
export { SecurityPartnerProviders };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/securityPartnerProviders/{securityPartnerProviderName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.securityPartnerProviderName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.SecurityPartnerProvider
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var updateTagsOperationSpec = {
    httpMethod: "PATCH",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/securityPartnerProviders/{securityPartnerProviderName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.securityPartnerProviderName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.TagsObject), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.SecurityPartnerProvider
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listByResourceGroupOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/securityPartnerProviders",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.SecurityPartnerProviderListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/providers/Microsoft.Network/securityPartnerProviders",
    urlParameters: [
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.SecurityPartnerProviderListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/securityPartnerProviders/{securityPartnerProviderName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.securityPartnerProviderName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/securityPartnerProviders/{securityPartnerProviderName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.securityPartnerProviderName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.SecurityPartnerProvider), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.SecurityPartnerProvider
        },
        201: {
            bodyMapper: Mappers.SecurityPartnerProvider
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listByResourceGroupNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.SecurityPartnerProviderListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.SecurityPartnerProviderListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=securityPartnerProviders.js.map