/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/subnetsMappers";
import * as Parameters from "../models/parameters";
/** Class representing a Subnets. */
var Subnets = /** @class */ (function () {
    /**
     * Create a Subnets.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function Subnets(client) {
        this.client = client;
    }
    /**
     * Deletes the specified subnet.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkName The name of the virtual network.
     * @param subnetName The name of the subnet.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    Subnets.prototype.deleteMethod = function (resourceGroupName, virtualNetworkName, subnetName, options) {
        return this.beginDeleteMethod(resourceGroupName, virtualNetworkName, subnetName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    Subnets.prototype.get = function (resourceGroupName, virtualNetworkName, subnetName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkName: virtualNetworkName,
            subnetName: subnetName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates or updates a subnet in the specified virtual network.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkName The name of the virtual network.
     * @param subnetName The name of the subnet.
     * @param subnetParameters Parameters supplied to the create or update subnet operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.SubnetsCreateOrUpdateResponse>
     */
    Subnets.prototype.createOrUpdate = function (resourceGroupName, virtualNetworkName, subnetName, subnetParameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, virtualNetworkName, subnetName, subnetParameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Prepares a subnet by applying network intent policies.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkName The name of the virtual network.
     * @param subnetName The name of the subnet.
     * @param prepareNetworkPoliciesRequestParameters Parameters supplied to prepare subnet by applying
     * network intent policies.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    Subnets.prototype.prepareNetworkPolicies = function (resourceGroupName, virtualNetworkName, subnetName, prepareNetworkPoliciesRequestParameters, options) {
        return this.beginPrepareNetworkPolicies(resourceGroupName, virtualNetworkName, subnetName, prepareNetworkPoliciesRequestParameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Unprepares a subnet by removing network intent policies.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkName The name of the virtual network.
     * @param subnetName The name of the subnet.
     * @param unprepareNetworkPoliciesRequestParameters Parameters supplied to unprepare subnet to
     * remove network intent policies.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    Subnets.prototype.unprepareNetworkPolicies = function (resourceGroupName, virtualNetworkName, subnetName, unprepareNetworkPoliciesRequestParameters, options) {
        return this.beginUnprepareNetworkPolicies(resourceGroupName, virtualNetworkName, subnetName, unprepareNetworkPoliciesRequestParameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    Subnets.prototype.list = function (resourceGroupName, virtualNetworkName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkName: virtualNetworkName,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Deletes the specified subnet.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkName The name of the virtual network.
     * @param subnetName The name of the subnet.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    Subnets.prototype.beginDeleteMethod = function (resourceGroupName, virtualNetworkName, subnetName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkName: virtualNetworkName,
            subnetName: subnetName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Creates or updates a subnet in the specified virtual network.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkName The name of the virtual network.
     * @param subnetName The name of the subnet.
     * @param subnetParameters Parameters supplied to the create or update subnet operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    Subnets.prototype.beginCreateOrUpdate = function (resourceGroupName, virtualNetworkName, subnetName, subnetParameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkName: virtualNetworkName,
            subnetName: subnetName,
            subnetParameters: subnetParameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    /**
     * Prepares a subnet by applying network intent policies.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkName The name of the virtual network.
     * @param subnetName The name of the subnet.
     * @param prepareNetworkPoliciesRequestParameters Parameters supplied to prepare subnet by applying
     * network intent policies.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    Subnets.prototype.beginPrepareNetworkPolicies = function (resourceGroupName, virtualNetworkName, subnetName, prepareNetworkPoliciesRequestParameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkName: virtualNetworkName,
            subnetName: subnetName,
            prepareNetworkPoliciesRequestParameters: prepareNetworkPoliciesRequestParameters,
            options: options
        }, beginPrepareNetworkPoliciesOperationSpec, options);
    };
    /**
     * Unprepares a subnet by removing network intent policies.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkName The name of the virtual network.
     * @param subnetName The name of the subnet.
     * @param unprepareNetworkPoliciesRequestParameters Parameters supplied to unprepare subnet to
     * remove network intent policies.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    Subnets.prototype.beginUnprepareNetworkPolicies = function (resourceGroupName, virtualNetworkName, subnetName, unprepareNetworkPoliciesRequestParameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkName: virtualNetworkName,
            subnetName: subnetName,
            unprepareNetworkPoliciesRequestParameters: unprepareNetworkPoliciesRequestParameters,
            options: options
        }, beginUnprepareNetworkPoliciesOperationSpec, options);
    };
    Subnets.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return Subnets;
}());
export { Subnets };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworks/{virtualNetworkName}/subnets/{subnetName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkName,
        Parameters.subnetName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0,
        Parameters.expand
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.Subnet
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworks/{virtualNetworkName}/subnets",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.SubnetListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworks/{virtualNetworkName}/subnets/{subnetName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkName,
        Parameters.subnetName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworks/{virtualNetworkName}/subnets/{subnetName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkName,
        Parameters.subnetName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "subnetParameters",
        mapper: __assign(__assign({}, Mappers.Subnet), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.Subnet
        },
        201: {
            bodyMapper: Mappers.Subnet
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginPrepareNetworkPoliciesOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworks/{virtualNetworkName}/subnets/{subnetName}/PrepareNetworkPolicies",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkName,
        Parameters.subnetName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "prepareNetworkPoliciesRequestParameters",
        mapper: __assign(__assign({}, Mappers.PrepareNetworkPoliciesRequest), { required: true })
    },
    responses: {
        200: {},
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginUnprepareNetworkPoliciesOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworks/{virtualNetworkName}/subnets/{subnetName}/UnprepareNetworkPolicies",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkName,
        Parameters.subnetName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "unprepareNetworkPoliciesRequestParameters",
        mapper: __assign(__assign({}, Mappers.UnprepareNetworkPoliciesRequest), { required: true })
    },
    responses: {
        200: {},
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.SubnetListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=subnets.js.map