/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/virtualNetworkPeeringsMappers";
import * as Parameters from "../models/parameters";
/** Class representing a VirtualNetworkPeerings. */
var VirtualNetworkPeerings = /** @class */ (function () {
    /**
     * Create a VirtualNetworkPeerings.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function VirtualNetworkPeerings(client) {
        this.client = client;
    }
    /**
     * Deletes the specified virtual network peering.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkName The name of the virtual network.
     * @param virtualNetworkPeeringName The name of the virtual network peering.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    VirtualNetworkPeerings.prototype.deleteMethod = function (resourceGroupName, virtualNetworkName, virtualNetworkPeeringName, options) {
        return this.beginDeleteMethod(resourceGroupName, virtualNetworkName, virtualNetworkPeeringName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    VirtualNetworkPeerings.prototype.get = function (resourceGroupName, virtualNetworkName, virtualNetworkPeeringName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkName: virtualNetworkName,
            virtualNetworkPeeringName: virtualNetworkPeeringName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates or updates a peering in the specified virtual network.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkName The name of the virtual network.
     * @param virtualNetworkPeeringName The name of the peering.
     * @param virtualNetworkPeeringParameters Parameters supplied to the create or update virtual
     * network peering operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualNetworkPeeringsCreateOrUpdateResponse>
     */
    VirtualNetworkPeerings.prototype.createOrUpdate = function (resourceGroupName, virtualNetworkName, virtualNetworkPeeringName, virtualNetworkPeeringParameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, virtualNetworkName, virtualNetworkPeeringName, virtualNetworkPeeringParameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    VirtualNetworkPeerings.prototype.list = function (resourceGroupName, virtualNetworkName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkName: virtualNetworkName,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Deletes the specified virtual network peering.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkName The name of the virtual network.
     * @param virtualNetworkPeeringName The name of the virtual network peering.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkPeerings.prototype.beginDeleteMethod = function (resourceGroupName, virtualNetworkName, virtualNetworkPeeringName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkName: virtualNetworkName,
            virtualNetworkPeeringName: virtualNetworkPeeringName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Creates or updates a peering in the specified virtual network.
     * @param resourceGroupName The name of the resource group.
     * @param virtualNetworkName The name of the virtual network.
     * @param virtualNetworkPeeringName The name of the peering.
     * @param virtualNetworkPeeringParameters Parameters supplied to the create or update virtual
     * network peering operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualNetworkPeerings.prototype.beginCreateOrUpdate = function (resourceGroupName, virtualNetworkName, virtualNetworkPeeringName, virtualNetworkPeeringParameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualNetworkName: virtualNetworkName,
            virtualNetworkPeeringName: virtualNetworkPeeringName,
            virtualNetworkPeeringParameters: virtualNetworkPeeringParameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    VirtualNetworkPeerings.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return VirtualNetworkPeerings;
}());
export { VirtualNetworkPeerings };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworks/{virtualNetworkName}/virtualNetworkPeerings/{virtualNetworkPeeringName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkName,
        Parameters.virtualNetworkPeeringName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.VirtualNetworkPeering
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworks/{virtualNetworkName}/virtualNetworkPeerings",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.VirtualNetworkPeeringListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworks/{virtualNetworkName}/virtualNetworkPeerings/{virtualNetworkPeeringName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkName,
        Parameters.virtualNetworkPeeringName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualNetworks/{virtualNetworkName}/virtualNetworkPeerings/{virtualNetworkPeeringName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualNetworkName,
        Parameters.virtualNetworkPeeringName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.syncRemoteAddressSpace,
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "virtualNetworkPeeringParameters",
        mapper: __assign(__assign({}, Mappers.VirtualNetworkPeering), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.VirtualNetworkPeering
        },
        201: {
            bodyMapper: Mappers.VirtualNetworkPeering
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.VirtualNetworkPeeringListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=virtualNetworkPeerings.js.map