import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import { NetworkManagementClientContext } from "../networkManagementClientContext";
/** Class representing a VirtualRouterPeerings. */
export declare class VirtualRouterPeerings {
    private readonly client;
    /**
     * Create a VirtualRouterPeerings.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    constructor(client: NetworkManagementClientContext);
    /**
     * Deletes the specified peering from a Virtual Router.
     * @param resourceGroupName The name of the resource group.
     * @param virtualRouterName The name of the Virtual Router.
     * @param peeringName The name of the peering.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    deleteMethod(resourceGroupName: string, virtualRouterName: string, peeringName: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * Gets the specified Virtual Router Peering.
     * @param resourceGroupName The name of the resource group.
     * @param virtualRouterName The name of the Virtual Router.
     * @param peeringName The name of the Virtual Router Peering.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualRouterPeeringsGetResponse>
     */
    get(resourceGroupName: string, virtualRouterName: string, peeringName: string, options?: msRest.RequestOptionsBase): Promise<Models.VirtualRouterPeeringsGetResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param virtualRouterName The name of the Virtual Router.
     * @param peeringName The name of the Virtual Router Peering.
     * @param callback The callback
     */
    get(resourceGroupName: string, virtualRouterName: string, peeringName: string, callback: msRest.ServiceCallback<Models.VirtualRouterPeering>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param virtualRouterName The name of the Virtual Router.
     * @param peeringName The name of the Virtual Router Peering.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, virtualRouterName: string, peeringName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.VirtualRouterPeering>): void;
    /**
     * Creates or updates the specified Virtual Router Peering.
     * @param resourceGroupName The name of the resource group.
     * @param virtualRouterName The name of the Virtual Router.
     * @param peeringName The name of the Virtual Router Peering.
     * @param parameters Parameters supplied to the create or update Virtual Router Peering operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualRouterPeeringsCreateOrUpdateResponse>
     */
    createOrUpdate(resourceGroupName: string, virtualRouterName: string, peeringName: string, parameters: Models.VirtualRouterPeering, options?: msRest.RequestOptionsBase): Promise<Models.VirtualRouterPeeringsCreateOrUpdateResponse>;
    /**
     * Lists all Virtual Router Peerings in a Virtual Router resource.
     * @param resourceGroupName The name of the resource group.
     * @param virtualRouterName The name of the Virtual Router.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualRouterPeeringsListResponse>
     */
    list(resourceGroupName: string, virtualRouterName: string, options?: msRest.RequestOptionsBase): Promise<Models.VirtualRouterPeeringsListResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param virtualRouterName The name of the Virtual Router.
     * @param callback The callback
     */
    list(resourceGroupName: string, virtualRouterName: string, callback: msRest.ServiceCallback<Models.VirtualRouterPeeringListResult>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param virtualRouterName The name of the Virtual Router.
     * @param options The optional parameters
     * @param callback The callback
     */
    list(resourceGroupName: string, virtualRouterName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.VirtualRouterPeeringListResult>): void;
    /**
     * Deletes the specified peering from a Virtual Router.
     * @param resourceGroupName The name of the resource group.
     * @param virtualRouterName The name of the Virtual Router.
     * @param peeringName The name of the peering.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginDeleteMethod(resourceGroupName: string, virtualRouterName: string, peeringName: string, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Creates or updates the specified Virtual Router Peering.
     * @param resourceGroupName The name of the resource group.
     * @param virtualRouterName The name of the Virtual Router.
     * @param peeringName The name of the Virtual Router Peering.
     * @param parameters Parameters supplied to the create or update Virtual Router Peering operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginCreateOrUpdate(resourceGroupName: string, virtualRouterName: string, peeringName: string, parameters: Models.VirtualRouterPeering, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Lists all Virtual Router Peerings in a Virtual Router resource.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualRouterPeeringsListNextResponse>
     */
    listNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.VirtualRouterPeeringsListNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.VirtualRouterPeeringListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.VirtualRouterPeeringListResult>): void;
}
//# sourceMappingURL=virtualRouterPeerings.d.ts.map