/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/virtualRouterPeeringsMappers";
import * as Parameters from "../models/parameters";
/** Class representing a VirtualRouterPeerings. */
var VirtualRouterPeerings = /** @class */ (function () {
    /**
     * Create a VirtualRouterPeerings.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function VirtualRouterPeerings(client) {
        this.client = client;
    }
    /**
     * Deletes the specified peering from a Virtual Router.
     * @param resourceGroupName The name of the resource group.
     * @param virtualRouterName The name of the Virtual Router.
     * @param peeringName The name of the peering.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    VirtualRouterPeerings.prototype.deleteMethod = function (resourceGroupName, virtualRouterName, peeringName, options) {
        return this.beginDeleteMethod(resourceGroupName, virtualRouterName, peeringName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    VirtualRouterPeerings.prototype.get = function (resourceGroupName, virtualRouterName, peeringName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            virtualRouterName: virtualRouterName,
            peeringName: peeringName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates or updates the specified Virtual Router Peering.
     * @param resourceGroupName The name of the resource group.
     * @param virtualRouterName The name of the Virtual Router.
     * @param peeringName The name of the Virtual Router Peering.
     * @param parameters Parameters supplied to the create or update Virtual Router Peering operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualRouterPeeringsCreateOrUpdateResponse>
     */
    VirtualRouterPeerings.prototype.createOrUpdate = function (resourceGroupName, virtualRouterName, peeringName, parameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, virtualRouterName, peeringName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    VirtualRouterPeerings.prototype.list = function (resourceGroupName, virtualRouterName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            virtualRouterName: virtualRouterName,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Deletes the specified peering from a Virtual Router.
     * @param resourceGroupName The name of the resource group.
     * @param virtualRouterName The name of the Virtual Router.
     * @param peeringName The name of the peering.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualRouterPeerings.prototype.beginDeleteMethod = function (resourceGroupName, virtualRouterName, peeringName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualRouterName: virtualRouterName,
            peeringName: peeringName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Creates or updates the specified Virtual Router Peering.
     * @param resourceGroupName The name of the resource group.
     * @param virtualRouterName The name of the Virtual Router.
     * @param peeringName The name of the Virtual Router Peering.
     * @param parameters Parameters supplied to the create or update Virtual Router Peering operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualRouterPeerings.prototype.beginCreateOrUpdate = function (resourceGroupName, virtualRouterName, peeringName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualRouterName: virtualRouterName,
            peeringName: peeringName,
            parameters: parameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    VirtualRouterPeerings.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return VirtualRouterPeerings;
}());
export { VirtualRouterPeerings };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualRouters/{virtualRouterName}/peerings/{peeringName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualRouterName,
        Parameters.peeringName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.VirtualRouterPeering
        },
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualRouters/{virtualRouterName}/peerings",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualRouterName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.VirtualRouterPeeringListResult
        },
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualRouters/{virtualRouterName}/peerings/{peeringName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualRouterName,
        Parameters.peeringName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualRouters/{virtualRouterName}/peerings/{peeringName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualRouterName,
        Parameters.peeringName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.VirtualRouterPeering), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.VirtualRouterPeering
        },
        201: {
            bodyMapper: Mappers.VirtualRouterPeering
        },
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.VirtualRouterPeeringListResult
        },
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
//# sourceMappingURL=virtualRouterPeerings.js.map