/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/vpnLinkConnectionsMappers";
import * as Parameters from "../models/parameters";
/** Class representing a VpnLinkConnections. */
var VpnLinkConnections = /** @class */ (function () {
    /**
     * Create a VpnLinkConnections.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function VpnLinkConnections(client) {
        this.client = client;
    }
    /**
     * Resets the VpnLink connection specified.
     * @param resourceGroupName The name of the resource group.
     * @param gatewayName The name of the gateway.
     * @param connectionName The name of the vpn connection.
     * @param linkConnectionName The name of the vpn link connection.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    VpnLinkConnections.prototype.resetConnection = function (resourceGroupName, gatewayName, connectionName, linkConnectionName, options) {
        return this.beginResetConnection(resourceGroupName, gatewayName, connectionName, linkConnectionName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Lists IKE Security Associations for Vpn Site Link Connection in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param gatewayName The name of the gateway.
     * @param connectionName The name of the vpn connection.
     * @param linkConnectionName The name of the vpn link connection.
     * @param [options] The optional parameters
     * @returns Promise<Models.VpnLinkConnectionsGetIkeSasResponse>
     */
    VpnLinkConnections.prototype.getIkeSas = function (resourceGroupName, gatewayName, connectionName, linkConnectionName, options) {
        return this.beginGetIkeSas(resourceGroupName, gatewayName, connectionName, linkConnectionName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    VpnLinkConnections.prototype.listByVpnConnection = function (resourceGroupName, gatewayName, connectionName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            gatewayName: gatewayName,
            connectionName: connectionName,
            options: options
        }, listByVpnConnectionOperationSpec, callback);
    };
    /**
     * Resets the VpnLink connection specified.
     * @param resourceGroupName The name of the resource group.
     * @param gatewayName The name of the gateway.
     * @param connectionName The name of the vpn connection.
     * @param linkConnectionName The name of the vpn link connection.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VpnLinkConnections.prototype.beginResetConnection = function (resourceGroupName, gatewayName, connectionName, linkConnectionName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            gatewayName: gatewayName,
            connectionName: connectionName,
            linkConnectionName: linkConnectionName,
            options: options
        }, beginResetConnectionOperationSpec, options);
    };
    /**
     * Lists IKE Security Associations for Vpn Site Link Connection in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param gatewayName The name of the gateway.
     * @param connectionName The name of the vpn connection.
     * @param linkConnectionName The name of the vpn link connection.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VpnLinkConnections.prototype.beginGetIkeSas = function (resourceGroupName, gatewayName, connectionName, linkConnectionName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            gatewayName: gatewayName,
            connectionName: connectionName,
            linkConnectionName: linkConnectionName,
            options: options
        }, beginGetIkeSasOperationSpec, options);
    };
    VpnLinkConnections.prototype.listByVpnConnectionNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listByVpnConnectionNextOperationSpec, callback);
    };
    return VpnLinkConnections;
}());
export { VpnLinkConnections };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var listByVpnConnectionOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/vpnGateways/{gatewayName}/vpnConnections/{connectionName}/vpnLinkConnections",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.gatewayName,
        Parameters.connectionName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ListVpnSiteLinkConnectionsResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginResetConnectionOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/vpnGateways/{gatewayName}/vpnConnections/{connectionName}/vpnLinkConnections/{linkConnectionName}/resetconnection",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.gatewayName,
        Parameters.connectionName,
        Parameters.linkConnectionName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        202: {},
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var beginGetIkeSasOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/vpnGateways/{gatewayName}/vpnConnections/{connectionName}/vpnLinkConnections/{linkConnectionName}/getikesas",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.gatewayName,
        Parameters.connectionName,
        Parameters.linkConnectionName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: {
                serializedName: "parsedResponse",
                type: {
                    name: "String"
                }
            }
        },
        202: {},
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var listByVpnConnectionNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ListVpnSiteLinkConnectionsResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=vpnLinkConnections.js.map