import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import { PrivateDnsManagementClientContext } from "../privateDnsManagementClientContext";
/** Class representing a PrivateZones. */
export declare class PrivateZones {
    private readonly client;
    /**
     * Create a PrivateZones.
     * @param {PrivateDnsManagementClientContext} client Reference to the service client.
     */
    constructor(client: PrivateDnsManagementClientContext);
    /**
     * Creates or updates a Private DNS zone. Does not modify Links to virtual networks or DNS records
     * within the zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param parameters Parameters supplied to the CreateOrUpdate operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.PrivateZonesCreateOrUpdateResponse>
     */
    createOrUpdate(resourceGroupName: string, privateZoneName: string, parameters: Models.PrivateZone, options?: Models.PrivateZonesCreateOrUpdateOptionalParams): Promise<Models.PrivateZonesCreateOrUpdateResponse>;
    /**
     * Updates a Private DNS zone. Does not modify virtual network links or DNS records within the
     * zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param parameters Parameters supplied to the Update operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.PrivateZonesUpdateResponse>
     */
    update(resourceGroupName: string, privateZoneName: string, parameters: Models.PrivateZone, options?: Models.PrivateZonesUpdateOptionalParams): Promise<Models.PrivateZonesUpdateResponse>;
    /**
     * Deletes a Private DNS zone. WARNING: All DNS records in the zone will also be deleted. This
     * operation cannot be undone. Private DNS zone cannot be deleted unless all virtual network links
     * to it are removed.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    deleteMethod(resourceGroupName: string, privateZoneName: string, options?: Models.PrivateZonesDeleteMethodOptionalParams): Promise<msRest.RestResponse>;
    /**
     * Gets a Private DNS zone. Retrieves the zone properties, but not the virtual networks links or
     * the record sets within the zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param [options] The optional parameters
     * @returns Promise<Models.PrivateZonesGetResponse>
     */
    get(resourceGroupName: string, privateZoneName: string, options?: msRest.RequestOptionsBase): Promise<Models.PrivateZonesGetResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param callback The callback
     */
    get(resourceGroupName: string, privateZoneName: string, callback: msRest.ServiceCallback<Models.PrivateZone>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, privateZoneName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.PrivateZone>): void;
    /**
     * Lists the Private DNS zones in all resource groups in a subscription.
     * @param [options] The optional parameters
     * @returns Promise<Models.PrivateZonesListResponse>
     */
    list(options?: Models.PrivateZonesListOptionalParams): Promise<Models.PrivateZonesListResponse>;
    /**
     * @param callback The callback
     */
    list(callback: msRest.ServiceCallback<Models.PrivateZoneListResult>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    list(options: Models.PrivateZonesListOptionalParams, callback: msRest.ServiceCallback<Models.PrivateZoneListResult>): void;
    /**
     * Lists the Private DNS zones within a resource group.
     * @param resourceGroupName The name of the resource group.
     * @param [options] The optional parameters
     * @returns Promise<Models.PrivateZonesListByResourceGroupResponse>
     */
    listByResourceGroup(resourceGroupName: string, options?: Models.PrivateZonesListByResourceGroupOptionalParams): Promise<Models.PrivateZonesListByResourceGroupResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param callback The callback
     */
    listByResourceGroup(resourceGroupName: string, callback: msRest.ServiceCallback<Models.PrivateZoneListResult>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByResourceGroup(resourceGroupName: string, options: Models.PrivateZonesListByResourceGroupOptionalParams, callback: msRest.ServiceCallback<Models.PrivateZoneListResult>): void;
    /**
     * Creates or updates a Private DNS zone. Does not modify Links to virtual networks or DNS records
     * within the zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param parameters Parameters supplied to the CreateOrUpdate operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginCreateOrUpdate(resourceGroupName: string, privateZoneName: string, parameters: Models.PrivateZone, options?: Models.PrivateZonesBeginCreateOrUpdateOptionalParams): Promise<msRestAzure.LROPoller>;
    /**
     * Updates a Private DNS zone. Does not modify virtual network links or DNS records within the
     * zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param parameters Parameters supplied to the Update operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginUpdate(resourceGroupName: string, privateZoneName: string, parameters: Models.PrivateZone, options?: Models.PrivateZonesBeginUpdateOptionalParams): Promise<msRestAzure.LROPoller>;
    /**
     * Deletes a Private DNS zone. WARNING: All DNS records in the zone will also be deleted. This
     * operation cannot be undone. Private DNS zone cannot be deleted unless all virtual network links
     * to it are removed.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginDeleteMethod(resourceGroupName: string, privateZoneName: string, options?: Models.PrivateZonesBeginDeleteMethodOptionalParams): Promise<msRestAzure.LROPoller>;
    /**
     * Lists the Private DNS zones in all resource groups in a subscription.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.PrivateZonesListNextResponse>
     */
    listNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.PrivateZonesListNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.PrivateZoneListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.PrivateZoneListResult>): void;
    /**
     * Lists the Private DNS zones within a resource group.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.PrivateZonesListByResourceGroupNextResponse>
     */
    listByResourceGroupNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.PrivateZonesListByResourceGroupNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listByResourceGroupNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.PrivateZoneListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByResourceGroupNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.PrivateZoneListResult>): void;
}
//# sourceMappingURL=privateZones.d.ts.map