import * as msRest from "@azure/ms-rest-js";
import * as Models from "../models";
import { ResourceManagementClientContext } from "../resourceManagementClientContext";
/** Class representing a DeploymentOperations. */
export declare class DeploymentOperations {
    private readonly client;
    /**
     * Create a DeploymentOperations.
     * @param {ResourceManagementClientContext} client Reference to the service client.
     */
    constructor(client: ResourceManagementClientContext);
    /**
     * Gets a deployments operation.
     * @param scope The resource scope.
     * @param deploymentName The name of the deployment.
     * @param operationId The ID of the operation to get.
     * @param [options] The optional parameters
     * @returns Promise<Models.DeploymentOperationsGetAtScopeResponse>
     */
    getAtScope(scope: string, deploymentName: string, operationId: string, options?: msRest.RequestOptionsBase): Promise<Models.DeploymentOperationsGetAtScopeResponse>;
    /**
     * @param scope The resource scope.
     * @param deploymentName The name of the deployment.
     * @param operationId The ID of the operation to get.
     * @param callback The callback
     */
    getAtScope(scope: string, deploymentName: string, operationId: string, callback: msRest.ServiceCallback<Models.DeploymentOperation>): void;
    /**
     * @param scope The resource scope.
     * @param deploymentName The name of the deployment.
     * @param operationId The ID of the operation to get.
     * @param options The optional parameters
     * @param callback The callback
     */
    getAtScope(scope: string, deploymentName: string, operationId: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DeploymentOperation>): void;
    /**
     * Gets all deployments operations for a deployment.
     * @param scope The resource scope.
     * @param deploymentName The name of the deployment.
     * @param [options] The optional parameters
     * @returns Promise<Models.DeploymentOperationsListAtScopeResponse>
     */
    listAtScope(scope: string, deploymentName: string, options?: Models.DeploymentOperationsListAtScopeOptionalParams): Promise<Models.DeploymentOperationsListAtScopeResponse>;
    /**
     * @param scope The resource scope.
     * @param deploymentName The name of the deployment.
     * @param callback The callback
     */
    listAtScope(scope: string, deploymentName: string, callback: msRest.ServiceCallback<Models.DeploymentOperationsListResult>): void;
    /**
     * @param scope The resource scope.
     * @param deploymentName The name of the deployment.
     * @param options The optional parameters
     * @param callback The callback
     */
    listAtScope(scope: string, deploymentName: string, options: Models.DeploymentOperationsListAtScopeOptionalParams, callback: msRest.ServiceCallback<Models.DeploymentOperationsListResult>): void;
    /**
     * Gets a deployments operation.
     * @param deploymentName The name of the deployment.
     * @param operationId The ID of the operation to get.
     * @param [options] The optional parameters
     * @returns Promise<Models.DeploymentOperationsGetAtTenantScopeResponse>
     */
    getAtTenantScope(deploymentName: string, operationId: string, options?: msRest.RequestOptionsBase): Promise<Models.DeploymentOperationsGetAtTenantScopeResponse>;
    /**
     * @param deploymentName The name of the deployment.
     * @param operationId The ID of the operation to get.
     * @param callback The callback
     */
    getAtTenantScope(deploymentName: string, operationId: string, callback: msRest.ServiceCallback<Models.DeploymentOperation>): void;
    /**
     * @param deploymentName The name of the deployment.
     * @param operationId The ID of the operation to get.
     * @param options The optional parameters
     * @param callback The callback
     */
    getAtTenantScope(deploymentName: string, operationId: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DeploymentOperation>): void;
    /**
     * Gets all deployments operations for a deployment.
     * @param deploymentName The name of the deployment.
     * @param [options] The optional parameters
     * @returns Promise<Models.DeploymentOperationsListAtTenantScopeResponse>
     */
    listAtTenantScope(deploymentName: string, options?: Models.DeploymentOperationsListAtTenantScopeOptionalParams): Promise<Models.DeploymentOperationsListAtTenantScopeResponse>;
    /**
     * @param deploymentName The name of the deployment.
     * @param callback The callback
     */
    listAtTenantScope(deploymentName: string, callback: msRest.ServiceCallback<Models.DeploymentOperationsListResult>): void;
    /**
     * @param deploymentName The name of the deployment.
     * @param options The optional parameters
     * @param callback The callback
     */
    listAtTenantScope(deploymentName: string, options: Models.DeploymentOperationsListAtTenantScopeOptionalParams, callback: msRest.ServiceCallback<Models.DeploymentOperationsListResult>): void;
    /**
     * Gets a deployments operation.
     * @param groupId The management group ID.
     * @param deploymentName The name of the deployment.
     * @param operationId The ID of the operation to get.
     * @param [options] The optional parameters
     * @returns Promise<Models.DeploymentOperationsGetAtManagementGroupScopeResponse>
     */
    getAtManagementGroupScope(groupId: string, deploymentName: string, operationId: string, options?: msRest.RequestOptionsBase): Promise<Models.DeploymentOperationsGetAtManagementGroupScopeResponse>;
    /**
     * @param groupId The management group ID.
     * @param deploymentName The name of the deployment.
     * @param operationId The ID of the operation to get.
     * @param callback The callback
     */
    getAtManagementGroupScope(groupId: string, deploymentName: string, operationId: string, callback: msRest.ServiceCallback<Models.DeploymentOperation>): void;
    /**
     * @param groupId The management group ID.
     * @param deploymentName The name of the deployment.
     * @param operationId The ID of the operation to get.
     * @param options The optional parameters
     * @param callback The callback
     */
    getAtManagementGroupScope(groupId: string, deploymentName: string, operationId: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DeploymentOperation>): void;
    /**
     * Gets all deployments operations for a deployment.
     * @param groupId The management group ID.
     * @param deploymentName The name of the deployment.
     * @param [options] The optional parameters
     * @returns Promise<Models.DeploymentOperationsListAtManagementGroupScopeResponse>
     */
    listAtManagementGroupScope(groupId: string, deploymentName: string, options?: Models.DeploymentOperationsListAtManagementGroupScopeOptionalParams): Promise<Models.DeploymentOperationsListAtManagementGroupScopeResponse>;
    /**
     * @param groupId The management group ID.
     * @param deploymentName The name of the deployment.
     * @param callback The callback
     */
    listAtManagementGroupScope(groupId: string, deploymentName: string, callback: msRest.ServiceCallback<Models.DeploymentOperationsListResult>): void;
    /**
     * @param groupId The management group ID.
     * @param deploymentName The name of the deployment.
     * @param options The optional parameters
     * @param callback The callback
     */
    listAtManagementGroupScope(groupId: string, deploymentName: string, options: Models.DeploymentOperationsListAtManagementGroupScopeOptionalParams, callback: msRest.ServiceCallback<Models.DeploymentOperationsListResult>): void;
    /**
     * Gets a deployments operation.
     * @param deploymentName The name of the deployment.
     * @param operationId The ID of the operation to get.
     * @param [options] The optional parameters
     * @returns Promise<Models.DeploymentOperationsGetAtSubscriptionScopeResponse>
     */
    getAtSubscriptionScope(deploymentName: string, operationId: string, options?: msRest.RequestOptionsBase): Promise<Models.DeploymentOperationsGetAtSubscriptionScopeResponse>;
    /**
     * @param deploymentName The name of the deployment.
     * @param operationId The ID of the operation to get.
     * @param callback The callback
     */
    getAtSubscriptionScope(deploymentName: string, operationId: string, callback: msRest.ServiceCallback<Models.DeploymentOperation>): void;
    /**
     * @param deploymentName The name of the deployment.
     * @param operationId The ID of the operation to get.
     * @param options The optional parameters
     * @param callback The callback
     */
    getAtSubscriptionScope(deploymentName: string, operationId: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DeploymentOperation>): void;
    /**
     * Gets all deployments operations for a deployment.
     * @param deploymentName The name of the deployment.
     * @param [options] The optional parameters
     * @returns Promise<Models.DeploymentOperationsListAtSubscriptionScopeResponse>
     */
    listAtSubscriptionScope(deploymentName: string, options?: Models.DeploymentOperationsListAtSubscriptionScopeOptionalParams): Promise<Models.DeploymentOperationsListAtSubscriptionScopeResponse>;
    /**
     * @param deploymentName The name of the deployment.
     * @param callback The callback
     */
    listAtSubscriptionScope(deploymentName: string, callback: msRest.ServiceCallback<Models.DeploymentOperationsListResult>): void;
    /**
     * @param deploymentName The name of the deployment.
     * @param options The optional parameters
     * @param callback The callback
     */
    listAtSubscriptionScope(deploymentName: string, options: Models.DeploymentOperationsListAtSubscriptionScopeOptionalParams, callback: msRest.ServiceCallback<Models.DeploymentOperationsListResult>): void;
    /**
     * Gets a deployments operation.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param deploymentName The name of the deployment.
     * @param operationId The ID of the operation to get.
     * @param [options] The optional parameters
     * @returns Promise<Models.DeploymentOperationsGetResponse>
     */
    get(resourceGroupName: string, deploymentName: string, operationId: string, options?: msRest.RequestOptionsBase): Promise<Models.DeploymentOperationsGetResponse>;
    /**
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param deploymentName The name of the deployment.
     * @param operationId The ID of the operation to get.
     * @param callback The callback
     */
    get(resourceGroupName: string, deploymentName: string, operationId: string, callback: msRest.ServiceCallback<Models.DeploymentOperation>): void;
    /**
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param deploymentName The name of the deployment.
     * @param operationId The ID of the operation to get.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, deploymentName: string, operationId: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DeploymentOperation>): void;
    /**
     * Gets all deployments operations for a deployment.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param deploymentName The name of the deployment.
     * @param [options] The optional parameters
     * @returns Promise<Models.DeploymentOperationsListResponse>
     */
    list(resourceGroupName: string, deploymentName: string, options?: Models.DeploymentOperationsListOptionalParams): Promise<Models.DeploymentOperationsListResponse>;
    /**
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param deploymentName The name of the deployment.
     * @param callback The callback
     */
    list(resourceGroupName: string, deploymentName: string, callback: msRest.ServiceCallback<Models.DeploymentOperationsListResult>): void;
    /**
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param deploymentName The name of the deployment.
     * @param options The optional parameters
     * @param callback The callback
     */
    list(resourceGroupName: string, deploymentName: string, options: Models.DeploymentOperationsListOptionalParams, callback: msRest.ServiceCallback<Models.DeploymentOperationsListResult>): void;
    /**
     * Gets all deployments operations for a deployment.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.DeploymentOperationsListAtScopeNextResponse>
     */
    listAtScopeNext(nextPageLink: string, options?: Models.DeploymentOperationsListAtScopeNextOptionalParams): Promise<Models.DeploymentOperationsListAtScopeNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listAtScopeNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.DeploymentOperationsListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listAtScopeNext(nextPageLink: string, options: Models.DeploymentOperationsListAtScopeNextOptionalParams, callback: msRest.ServiceCallback<Models.DeploymentOperationsListResult>): void;
    /**
     * Gets all deployments operations for a deployment.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.DeploymentOperationsListAtTenantScopeNextResponse>
     */
    listAtTenantScopeNext(nextPageLink: string, options?: Models.DeploymentOperationsListAtTenantScopeNextOptionalParams): Promise<Models.DeploymentOperationsListAtTenantScopeNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listAtTenantScopeNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.DeploymentOperationsListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listAtTenantScopeNext(nextPageLink: string, options: Models.DeploymentOperationsListAtTenantScopeNextOptionalParams, callback: msRest.ServiceCallback<Models.DeploymentOperationsListResult>): void;
    /**
     * Gets all deployments operations for a deployment.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.DeploymentOperationsListAtManagementGroupScopeNextResponse>
     */
    listAtManagementGroupScopeNext(nextPageLink: string, options?: Models.DeploymentOperationsListAtManagementGroupScopeNextOptionalParams): Promise<Models.DeploymentOperationsListAtManagementGroupScopeNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listAtManagementGroupScopeNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.DeploymentOperationsListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listAtManagementGroupScopeNext(nextPageLink: string, options: Models.DeploymentOperationsListAtManagementGroupScopeNextOptionalParams, callback: msRest.ServiceCallback<Models.DeploymentOperationsListResult>): void;
    /**
     * Gets all deployments operations for a deployment.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.DeploymentOperationsListAtSubscriptionScopeNextResponse>
     */
    listAtSubscriptionScopeNext(nextPageLink: string, options?: Models.DeploymentOperationsListAtSubscriptionScopeNextOptionalParams): Promise<Models.DeploymentOperationsListAtSubscriptionScopeNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listAtSubscriptionScopeNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.DeploymentOperationsListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listAtSubscriptionScopeNext(nextPageLink: string, options: Models.DeploymentOperationsListAtSubscriptionScopeNextOptionalParams, callback: msRest.ServiceCallback<Models.DeploymentOperationsListResult>): void;
    /**
     * Gets all deployments operations for a deployment.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.DeploymentOperationsListNextResponse>
     */
    listNext(nextPageLink: string, options?: Models.DeploymentOperationsListNextOptionalParams): Promise<Models.DeploymentOperationsListNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.DeploymentOperationsListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: Models.DeploymentOperationsListNextOptionalParams, callback: msRest.ServiceCallback<Models.DeploymentOperationsListResult>): void;
}
//# sourceMappingURL=deploymentOperations.d.ts.map